@@ -126,7 +126,7 @@
 #' `r man_get_image_tag(file = "man_data_color_2.png")`
 #' }}
 #'
-#' @family Format Data
+#' @family data formatting functions
 #' @section Function ID:
 #' 3-21
 #'
@@ -155,21 +155,21 @@ data_color <- function(
   # Evaluate `colors` with `eval_tidy()` (supports quosures)
   colors <- rlang::eval_tidy(colors, data_tbl)
 
-  # Collect the column names from `data_tbl`
-  colnames <- names(data_tbl)
-
   # Resolution of `columns` as column names in the table
-  #columns <- rlang::enquo(columns)
-  resolved_columns <-
-    resolve_cols_c(expr = {{ columns }}, data = data)
+  resolved_columns <- resolve_cols_c(expr = {{ columns }}, data = data)
 
   # Get the sequence of row indices for the table
   rows <- seq_len(nrow(data_tbl))
 
   data_color_styles_tbl <-
     dplyr::tibble(
-      locname = character(0), grpname = character(0), colname = character(0),
-      locnum = numeric(0), rownum = integer(0), colnum = integer(0), styles = list()
+      locname = character(0),
+      grpname = character(0),
+      colname = character(0),
+      locnum = numeric(0),
+      rownum = integer(0),
+      colnum = integer(0),
+      styles = list()
     )
 
   for (column in resolved_columns) {
@@ -181,7 +181,12 @@ data_color <- function(
       if (is.numeric(data_vals)) {
 
         # Create a color function based on `scales::col_numeric()`
-        color_fn <- scales::col_numeric(palette = colors, domain = data_vals, alpha = TRUE)
+        color_fn <-
+          scales::col_numeric(
+            palette = colors,
+            domain = data_vals,
+            alpha = TRUE
+          )
 
       } else if (is.character(data_vals) || is.factor(data_vals)) {
 
@@ -191,24 +196,32 @@ data_color <- function(
         # of levels. Instead, colors should be subsetted. scales does the right
         # thing for palette names though, so we need to screen those cases out.
         if (length(colors) > 1) {
+
           nlvl <-
             if (is.factor(data_vals)) {
               nlevels(data_vals)
             } else {
               nlevels(factor(data_vals))
             }
+
           if (length(colors) > nlvl) {
             colors <- colors[seq_len(nlvl)]
           }
         }
 
         # Create a color function based on `scales::col_factor()`
-        color_fn <- scales::col_factor(palette = colors, domain = data_vals, alpha = TRUE)
+        color_fn <-
+          scales::col_factor(
+            palette = colors,
+            domain = data_vals,
+            alpha = TRUE
+          )
 
       } else {
 
-        stop("Don't know how to map colors to a column of class ", class(data_vals)[1], ".",
-             call. = FALSE)
+        cli::cli_abort(
+          "Don't know how to map colors to a column of class {class(data_vals)[1]}."
+        )
       }
 
     } else if (inherits(colors, "function")) {
@@ -217,9 +230,9 @@ data_color <- function(
       color_fn <- colors
 
     } else {
-
-      stop("The `colors` arg must be either a character vector of colors or a function",
-           call. = FALSE)
+      cli::cli_abort(
+        "The `colors` arg must be either a character vector of colors or a function."
+      )
     }
 
     # Evaluate `color_fn` with `eval_tidy()` (supports quosures)
@@ -243,7 +256,8 @@ data_color <- function(
       dplyr::bind_rows(
         data_color_styles_tbl,
         generate_data_color_styles_tbl(
-          column = column, rows = rows,
+          column = column,
+          rows = rows,
           color_styles = color_styles
         )
       )
@@ -258,7 +272,8 @@ data_color <- function(
         dplyr::bind_rows(
           data_color_styles_tbl,
           generate_data_color_styles_tbl(
-            column = column, rows = rows,
+            column = column,
+            rows = rows,
             color_styles = color_styles
           )
         )
@@ -274,8 +289,12 @@ data_color <- function(
 generate_data_color_styles_tbl <- function(column, rows, color_styles) {
 
   dplyr::tibble(
-    locname = "data", grpname = NA_character_,
-    colname = column, locnum = 5, rownum = rows,
+    locname = "data",
+    grpname = NA_character_,
+    colname = column,
+    locnum = 5,
+    rownum = rows,
+    colnum = NA_integer_,
     styles = color_styles
   )
 }
@@ -378,19 +397,19 @@ rgba_to_hex <- function(colors) {
 
   colors_vec[!colors_rgba] <- colors[!colors_rgba]
 
+  rgba_str <- gsub("(rgba\\(|\\))", "", colors[colors_rgba])
+
+  rgba_vec <- as.numeric(unlist(strsplit(rgba_str, ",")))
+
   color_matrix <-
-    colors[colors_rgba] %>%
-    gsub(pattern = "(rgba\\(|\\))", replacement = "", x = .) %>%
-    strsplit(",") %>%
-    unlist() %>%
-    as.numeric() %>%
     matrix(
-      ., ncol = 4,
+      rgba_vec,
+      ncol = 4,
       dimnames = list(c(), c("r", "g", "b", "alpha")),
       byrow = TRUE
     )
 
-  alpha <- color_matrix[, "alpha"] %>% unname()
+  alpha <- unname(color_matrix[, "alpha"])
 
   # Convert color matrix to hexadecimal colors in the #RRGGBBAA format
   colors_to_hex <-
@@ -420,7 +439,8 @@ html_color <- function(colors, alpha = NULL) {
 
   # Stop function if there are any NA values in `colors`
   if (any(is.na(colors))) {
-    stop("No values supplied in `colors` should be NA")
+
+    cli::cli_abort("No values supplied in `colors` should be `NA`.")
   }
 
   is_rgba <- is_rgba_col(colors = colors)
@@ -521,8 +541,7 @@ normalize_colors <- function(colors, alpha) {
 
   # Generate rgba() color values for `colors_html`
   colors_html[!colors_alpha_1] <-
-    color_matrix[!colors_alpha_1, , drop = FALSE] %>%
-    col_matrix_to_rgba()
+    col_matrix_to_rgba(color_matrix[!colors_alpha_1, , drop = FALSE])
 
   colors_html
 }
@@ -533,13 +552,10 @@ css_exclusive_colors <- function() {
 
   color_values <- color_tbl_subset[["hexadecimal"]]
 
-  color_values <-
-    stats::setNames(
-      color_values,
-      tolower(color_tbl_subset[["color_name"]])
-    )
-
-  color_values
+  stats::setNames(
+    color_values,
+    tolower(color_tbl_subset[["color_name"]])
+  )
 }
 
 valid_color_names <- function() {
@@ -554,14 +570,16 @@ check_named_colors <- function(named_colors) {
 
     invalid_colors <- base::setdiff(unique(named_colors), valid_color_names())
 
-    stop(
+    one_several_invalid <-
       ifelse(
         length(invalid_colors) > 1,
         "Several invalid color names were ",
         "An invalid color name was "
-      ), "used (", str_catalog(invalid_colors, conj = "and"), "):\n",
-      " * Only R/X11 color names and CSS 3.0 color names can be used",
-      call. = FALSE
-    )
+      )
+
+    cli::cli_abort(c(
+      "{one_several_invalid} used ({str_catalog(invalid_colors, conj = 'and')}).",
+      "*" = "Only R/X11 color names and CSS 3.0 color names can be used."
+    ))
   }
 }
