@@ -1,13 +1,11 @@
 .dt_data_key <- "_data"
 
 dt_data_get <- function(data) {
-
   dt__get(data, .dt_data_key)
 }
 
 dt_data_set <- function(data, data_tbl) {
-
-  dt__set(data, .dt_data_key, data_tbl %>% dplyr::as_tibble())
+  dt__set(data, .dt_data_key, dplyr::as_tibble(data_tbl))
 }
 
 # rownames_to_column is a string; if not NA, it means the row.names(data_tbl)
@@ -20,9 +18,10 @@ dt_data_init <- function(data, data_tbl, rownames_to_column = NA) {
 
     if (rownames_to_column %in% colnames(data_tbl)) {
 
-      stop("Reserved column name `", rownames_to_column, "` was detected in ",
-        "the data; please rename this column",
-        call. = FALSE)
+      cli::cli_abort(c(
+        "Reserved column name `{rownames_to_column}` was detected in the data.",
+        "*" = "Please rename this column."
+      ))
     }
 
     data_tbl <-
