@@ -1,19 +1,19 @@
 .dt_stub_df_key <- "_stub_df"
 
 dt_stub_df_get <- function(data) {
-
   dt__get(data, .dt_stub_df_key)
 }
 
 dt_stub_df_set <- function(data, stub_df) {
-
   dt__set(data, .dt_stub_df_key, stub_df)
 }
 
-dt_stub_df_init <- function(data,
-                            rowname_col,
-                            groupname_col,
-                            row_group.sep) {
+dt_stub_df_init <- function(
+    data,
+    rowname_col,
+    groupname_col,
+    row_group.sep
+) {
 
   data_tbl <- dt_data_get(data = data)
 
@@ -23,27 +23,54 @@ dt_stub_df_init <- function(data,
       rownum_i = seq_len(nrow(data_tbl)),
       group_id = rep(NA_character_, nrow(data_tbl)),
       rowname = rep(NA_character_, nrow(data_tbl)),
+      row_id = rep(NA_character_, nrow(data_tbl)),
       group_label = rep(list(NULL), nrow(data_tbl)),
+      indent = rep(NA_character_, nrow(data_tbl)),
       built = rep(NA_character_, nrow(data_tbl))
     )
 
-  # If `rowname` is a column available in `data`,
-  # place that column's data into `stub_df` and
-  # remove it from `data`
+  # Put the `rowname_cols`'s data into `stub_df`
   if (!is.null(rowname_col) && rowname_col %in% colnames(data_tbl)) {
 
-    data <- data %>% dt_boxhead_set_stub(var = rowname_col)
+    data <- dt_boxhead_set_stub(data = data, var = rowname_col)
+
+    rownames <- data_tbl[[rowname_col]]
 
     # Place the `rowname` values into `stub_df$rowname`
-    stub_df[["rowname"]] <- as.character(data_tbl[[rowname_col]])
+    stub_df[["rowname"]] <- as.character(rownames)
+
+    #
+    # Develop unique ID values for the `row_id` values
+    #
+
+    row_id <- rep(NA_character_, length(rownames))
+
+    for (i in seq_along(rownames)) {
+
+      if (is.na(rownames[i])) {
+        row_id[i] <- as.character(i)
+      }
+
+      if (!is.na(rownames[i])) {
+        row_id[i] <- rownames[i]
+
+        if (i > 1 && row_id[i] %in% row_id[1:(i - 1)]) {
+          row_id[i] <- paste0(row_id[i], "__", i)
+        }
+      }
+    }
+
+    stub_df[["row_id"]] <- row_id
   }
 
   # If `data` is a `grouped_df` then create groups from the
   # group columns; note that this will overwrite any values
   # already in `stub_df$group_id`
-  if (!is.null(groupname_col) &&
-      length(groupname_col) > 0 &&
-      all(groupname_col %in% colnames(data_tbl))) {
+  if (
+    !is.null(groupname_col) &&
+    length(groupname_col) > 0 &&
+    all(groupname_col %in% colnames(data_tbl))
+  ) {
 
     row_group_ids <-
       apply(
@@ -57,26 +84,24 @@ dt_stub_df_init <- function(data,
     stub_df[["group_id"]] <- row_group_ids
     stub_df[["group_label"]] <- as.list(row_group_ids)
 
-    data <- data %>% dt_boxhead_set_row_group(vars = groupname_col)
+    data <- dt_boxhead_set_row_group(data = data, vars = groupname_col)
   }
 
-  # Stop if input `data` has no columns (after modifying
-  # `data` for groups)
+  # Stop if input `data` has no columns (after modifying `data` for groups)
   if (ncol(data_tbl) == 0) {
-    stop("The `data` must have at least one column that isn't a 'group' column.",
-         call. = FALSE)
+    cli::cli_abort(
+      "The `data` must have at least one column that isn't a 'group' column."
+    )
   }
 
-  data %>% dt_stub_df_set(stub_df = stub_df)
+  dt_stub_df_set(data = data, stub_df = stub_df)
 }
 
 dt_stub_df_exists <- function(data) {
 
   stub_df <- dt_stub_df_get(data = data)
 
-  available <- !all(is.na((stub_df)[["rowname"]]))
-
-  available
+  !all(is.na((stub_df)[["rowname"]]))
 }
 
 dt_stub_df_build <- function(data, context) {
@@ -88,7 +113,6 @@ dt_stub_df_build <- function(data, context) {
       stub_df$group_label,
       FUN.VALUE = character(1),
       FUN = function(label) {
-
         if (!is.null(label)) {
           process_text(label, context)
         } else {
@@ -97,9 +121,7 @@ dt_stub_df_build <- function(data, context) {
       }
     )
 
-  data <- dt_stub_df_set(data = data, stub_df = stub_df)
-
-  data
+  dt_stub_df_set(data = data, stub_df = stub_df)
 }
 
 # Function to obtain a reordered version of `stub_df`
@@ -117,7 +139,7 @@ reorder_stub_df <- function(data) {
 
   stub_df <- stub_df[rows_df$rownum_final, ]
 
-  stub_df %>% dt_stub_df_set(data = data)
+  dt_stub_df_set(data = data, stub_df = stub_df)
 }
 
 dt_stub_groupname_has_na <- function(data) {
@@ -148,7 +170,6 @@ dt_stub_components <- function(data) {
 # `rowname` part is available; TRUE indicates that we are working with a table
 # with rownames
 dt_stub_components_is_rowname <- function(stub_components) {
-
   identical(stub_components, "rowname")
 }
 
@@ -156,7 +177,6 @@ dt_stub_components_is_rowname <- function(stub_components) {
 # `group_id` part is available; TRUE indicates that we are working with a table
 # with groups but it doesn't have rownames
 dt_stub_components_is_groupname <- function(stub_components) {
-
   identical(stub_components, "group_id")
 }
 
@@ -164,12 +184,10 @@ dt_stub_components_is_groupname <- function(stub_components) {
 # `rowname` and `group_id` parts are available; TRUE indicates that we are
 # working with a table with rownames and groups
 dt_stub_components_is_rowname_groupname <- function(stub_components) {
-
   identical(stub_components, c("group_id", "rowname"))
 }
 
 dt_stub_components_has_rowname <- function(stub_components) {
-
   isTRUE("rowname" %in% stub_components)
 }
 
@@ -181,7 +199,16 @@ dt_stub_rowname_at_position <- function(data, i) {
     return(NULL)
   }
 
-  stub_df <- dt_stub_df_get(data = data)
+  dt_stub_df_get(data = data)$rowname[[i]]
+}
 
-  stub_df$rowname[[i]]
+dt_stub_indentation_at_position <- function(data, i) {
+
+  indent_i <- dt_stub_df_get(data = data)$indent[[i]]
+
+  if (is.na(indent_i)) {
+    return(NULL)
+  }
+
+  as.integer(indent_i)
 }
