@@ -37,7 +37,7 @@
 #' `r man_get_image_tag(file = "man_tab_header_1.png")`
 #' }}
 #'
-#' @family Create or Modify Parts
+#' @family part creation/modification functions
 #' @section Function ID:
 #' 2-1
 #'
@@ -123,7 +123,7 @@ tab_header <- function(
 #' `r man_get_image_tag(file = "man_tab_spanner_1.png")`
 #' }}
 #'
-#' @family Create or Modify Parts
+#' @family part creation/modification functions
 #' @section Function ID:
 #' 2-2
 #'
@@ -161,11 +161,10 @@ tab_spanner <- function(
 
   # Stop function if `level` is provided and is less than `1`
   if (!is.null(level) && level < 1) {
-    stop(
-      "A spanner level of ", level, " cannot be set:\n",
-      "* Please choose a `level` value greater than or equal to `1`",
-      call. = FALSE
-    )
+    cli::cli_abort(c(
+      "A spanner level of {level} cannot be set.",
+      "*" = "Please choose a `level` value greater than or equal to `1`."
+    ))
   }
 
   if (is.numeric(spanner_id_idx)) {
@@ -185,11 +184,10 @@ tab_spanner <- function(
           collapse = ", "
         )
 
-      stop(
-        "One or more spanner ID(s) supplied in `spanners` (", error_vars, ") ",
-        "for the new spanner with the ID `",  id, "` doesn't belong to any ",
-        "existing spanners.",
-        call. = FALSE
+      cli::cli_abort(
+        "One or more spanner ID(s) supplied in `spanners` ({error_vars}),
+        for the new spanner with the ID `{id}` doesn't belong to any
+        existing spanners."
       )
     }
 
@@ -202,7 +200,8 @@ tab_spanner <- function(
     return(data)
   }
 
-  # Check new `id` against existing `id` values and stop if necessary
+  # Check new `id` against existing `id` values across column labels
+  # and spanner column labels and stop if necessary
   check_spanner_id_unique(data = data, spanner_id = id)
 
   # Resolve the `column_names` that new spanner will span over
@@ -366,7 +365,7 @@ resolve_spanned_column_names <- function(
 #' `r man_get_image_tag(file = "man_tab_spanner_delim_1.png")`
 #' }}
 #'
-#' @family Create or Modify Parts
+#' @family part creation/modification functions
 #' @section Function ID:
 #' 2-3
 #'
@@ -392,6 +391,7 @@ tab_spanner_delim <- function(
       expr = {{ columns }},
       data = data
     )
+
   if (!is.null(columns)) {
     colnames_spanners <- base::intersect(all_cols, columns)
   } else {
@@ -483,17 +483,42 @@ tab_spanner_delim <- function(
     spanners_i_values <- rle_spanners_i$values
     spanners_i_col_i <- utils::head(cumsum(c(1, spanners_i_lengths)), -1)
 
+    spanner_id_vals <- c()
+
     for (j in seq_along(spanners_i_lengths)) {
 
       if (!is.na(spanners_i_values[j])) {
 
-        # Obtain the ID for the spanner
+        # Construct the ID for the spanner from the spanner matrix
         spanner_id <-
-          paste(
-            spanner_matrix[seq(i, nrow(spanner_matrix)), spanners_i_col_i[j]],
-            collapse = delim
+          paste0(
+            "spanner-",
+            paste(
+              spanner_matrix[seq(i, nrow(spanner_matrix)), spanners_i_col_i[j]],
+              collapse = delim
+            )
           )
 
+        # Modify `spanner_id` to not collide with any other values
+        if (spanner_id %in% spanner_id_vals) {
+
+          if (grepl("^spanner-", spanner_id)) {
+
+            # Add number to spanner ID values on first duplication
+            spanner_id <- gsub("^spanner-", "spanner:1-", spanner_id)
+          }
+
+          while (spanner_id %in% spanner_id_vals) {
+
+            # Increment number to spanner ID values on subsequent duplications
+            idx_str <- gsub("^spanner:([0-9]+)-.*", "\\1", spanner_id)
+            idx_int <- as.integer(idx_str)
+            spanner_id <- gsub("^(spanner:)[0-9]+(-.*)", paste0("\\1", idx_int + 1, "\\2"), spanner_id)
+          }
+        }
+
+        spanner_id_vals <- unique(c(spanner_id_vals, spanner_id))
+
         spanner_columns <-
           seq(
             spanners_i_col_i[j],
@@ -611,7 +636,7 @@ tab_spanner_delim <- function(
 #' `r man_get_image_tag(file = "man_tab_row_group_2.png")`
 #' }}
 #'
-#' @family Create or Modify Parts
+#' @family part creation/modification functions
 #' @section Function ID:
 #' 2-4
 #'
@@ -637,11 +662,10 @@ tab_row_group <- function(
       label <- group
     }
 
-    warning(
-      "The `group` argument has been deprecated in gt 0.3.0:\n",
-      "* use the `label` argument to specify the group label.",
-      call. = FALSE
-    )
+    cli::cli_warn(c(
+      "Since gt v0.3.0 the `group` argument has been deprecated.",
+      "*" =  "Use the `label` argument to specify the group label."
+    ))
   }
 
   # Warn user about `others_label` deprecation
@@ -653,11 +677,11 @@ tab_row_group <- function(
         row_group.default_label = others_label
       )
 
-    warning(
-      "The `others_label` argument has been deprecated in gt 0.3.0:\n",
-      "* use `tab_options(row_group.default_label = <label>)` to set this label.",
-      call. = FALSE
-    )
+    cli::cli_warn(c(
+      "Since gt v0.3.0 the `others_label` argument has been deprecated.",
+      "*" = "Use `tab_options(row_group.default_label = <label>)` to set
+      this label."
+    ))
 
     if (missing(label) && missing(rows) && missing(id)) {
       return(data)
@@ -672,7 +696,6 @@ tab_row_group <- function(
 
   # Get the `stub_df` data frame from `data`
   stub_df <- dt_stub_df_get(data = data)
-  data_tbl <- dt_data_get(data = data)
 
   # Resolve the row numbers using the `resolve_vars` function
   resolved_rows_idx <-
@@ -744,7 +767,7 @@ tab_row_group <- function(
 #' `r man_get_image_tag(file = "man_tab_stubhead_1.png")`
 #' }}
 #'
-#' @family Create or Modify Parts
+#' @family part creation/modification functions
 #' @section Function ID:
 #' 2-5
 #'
@@ -760,6 +783,176 @@ tab_stubhead <- function(
   dt_stubhead_label(data = data, label = label)
 }
 
+#' Control indentation of row labels in the stub
+#'
+#' @description
+#' Indentation of row labels is an effective way for establishing structure in a
+#' table stub. The `tab_stub_indent()` function allows for fine control over
+#' row label indentation through either explicit definition of an indentation
+#' level, or, by way of an indentation directive using keywords.
+#'
+#' @inheritParams fmt_number
+#' @param rows The rows to consider for the indentation change. Can either be a
+#'   vector of row captions provided in `c()`, a vector of row indices, or a
+#'   helper function focused on selections. The select helper functions are:
+#'   [starts_with()], [ends_with()], [contains()], [matches()], [one_of()], and
+#'   [everything()].
+#' @param indent An indentation directive either as a keyword describing the
+#'   indentation change or as an explicit integer value for directly setting the
+#'   indentation level. The keyword `"increase"` (the default) will increase the
+#'   indentation level by one; `"decrease"` will do the same in the reverse
+#'   direction. The starting indentation level of `0` means no indentation and
+#'   this values serves as a lower bound. The upper bound for indentation is at
+#'   level `5`.
+#'
+#' @return An object of class `gt_tbl`.
+#'
+#' @section Examples:
+#'
+#' Use [`pizzaplace`] to create a **gt** table. With `tab_stub_indent()` we can
+#' add indentation to targeted row labels in the stub. Here we target the
+#' different pizza sizes and avoid selecting the repeating `"All Sizes"` row
+#' label.
+#'
+#' ```r
+#' dplyr::bind_rows(
+#'   pizzaplace %>%
+#'     dplyr::group_by(type, size) %>%
+#'     dplyr::summarize(
+#'       sold = n(),
+#'       income = sum(price),
+#'       .groups = "drop_last"
+#'     ) %>%
+#'     dplyr::summarize(
+#'       sold = sum(sold),
+#'       income = sum(income),
+#'       size = "All Sizes",
+#'       .groups = "drop"
+#'     ),
+#'   pizzaplace %>%
+#'     dplyr::group_by(type, size) %>%
+#'     dplyr::summarize(
+#'       sold = n(),
+#'       income = sum(price),
+#'       .groups = "drop"
+#'     )
+#' ) %>%
+#'   gt(rowname_col = "size", groupname_col = "type") %>%
+#'   tab_header(title = "Pizzas Sold in 2015") %>%
+#'   fmt_number(
+#'     columns = sold,
+#'     decimals = 0,
+#'     use_seps = TRUE
+#'   ) %>%
+#'   fmt_currency(
+#'     columns = income,
+#'     currency = "USD"
+#'   ) %>%
+#'   tab_options(
+#'     summary_row.background.color = "#ACEACE",
+#'     row_group.background.color = "#FFEFDB",
+#'     row_group.as_column = TRUE
+#'   ) %>%
+#'   tab_stub_indent(
+#'     rows = matches("^L|^M|^S|^XL|^XXL"),
+#'     indent = 2
+#'   ) %>%
+#'   tab_style(
+#'     style = cell_fill(color = "gray95"),
+#'     locations = list(
+#'       cells_body(rows = matches("^All")),
+#'       cells_stub(rows = matches("^All"))
+#'     )
+#'   )
+#' ```
+#'
+#' \if{html}{\out{
+#' `r man_get_image_tag(file = "man_tab_stub_indent_1.png")`
+#' }}
+#'
+#' @family part creation/modification functions
+#' @section Function ID:
+#' 2-6
+#'
+#' @export
+tab_stub_indent <- function(
+    data,
+    rows,
+    indent = "increase"
+) {
+
+  # Perform input object validation
+  stop_if_not_gt(data = data)
+
+  # Capture the `rows` expression
+  row_expr <- rlang::enquo(rows)
+
+  # Get the `stub_df` data frame from `data`
+  stub_df <- dt_stub_df_get(data = data)
+
+  # Resolve the row numbers using the `resolve_vars` function
+  resolved_rows_idx <-
+    resolve_rows_i(
+      expr = !!row_expr,
+      data = data
+    )
+
+  # Set indent levels appropriately
+  indent_vals <- stub_df[stub_df$rownum_i %in% resolved_rows_idx, ][["indent"]]
+
+  for (i in seq_along(indent_vals)) {
+
+    if (is.na(indent_vals[i])) {
+      indent_val_i <- 0L
+    } else if (grepl("^[0-9]$", indent_vals[i])) {
+      indent_val_i <- as.integer(indent_vals[i])
+    } else {
+      indent_val_i <- indent_vals[i]
+    }
+
+    # Modify `indent_val_i` based on keyword directives
+    if (is.character(indent)) {
+
+      # Move `indent_val_i` up or down by one
+      if (indent == "increase") {
+        indent_val_i <- indent_val_i + 1L
+      } else if (indent == "decrease") {
+        indent_val_i <- indent_val_i - 1L
+      }
+
+      # Set hard boundaries on the indentation value (LB is `0`, UB is `5`)
+      if (indent_val_i > 5) indent_val_i <- 5L
+      if (indent_val_i < 0) indent_val_i <- 0L
+    }
+
+    # Modify `indent_val_i` using a fixed value
+    if (
+      is.numeric(indent) &&
+      !is.na(indent) &&
+      !is.infinite(indent)
+    ) {
+
+      # Stop function if `indent` value doesn't fall into the acceptable range
+      if (indent < 0 | indent > 5) {
+        cli::cli_abort(c(
+          "If given as a numeric value, `indent` should be one of the following:",
+          "*" = "0, 1, 2, 3, 4, or 5"
+        ))
+      }
+
+      # Coerce `indent` to an integer value
+      indent_val_i <- as.integer(indent)
+    }
+
+    # Ensure that `indent_val_i` is assigned to indent_vals as a character value
+    indent_vals[i] <- as.character(indent_val_i)
+  }
+
+  stub_df[stub_df$rownum_i %in% resolved_rows_idx, ][["indent"]] <- indent_vals
+
+  dt_stub_df_set(data = data, stub_df = stub_df)
+}
+
 #' Add a table footnote
 #'
 #' @description
@@ -841,9 +1034,9 @@ tab_stubhead <- function(
 #' `r man_get_image_tag(file = "man_tab_footnote_1.png")`
 #' }}
 #'
-#' @family Create or Modify Parts
+#' @family part creation/modification functions
 #' @section Function ID:
-#' 2-6
+#' 2-7
 #'
 #' @export
 tab_footnote <- function(
@@ -1033,7 +1226,6 @@ set_footnote.cells_body <- function(loc, data, footnote, placement) {
 
   resolved <- resolve_cells_body(data = data, object = loc)
 
-  cols <- resolved$columns
   rows <- resolved$rows
 
   colnames <- resolved$colnames
@@ -1120,14 +1312,14 @@ set_footnote.cells_stub_grand_summary <- function(loc, data, footnote, placement
 
 set_footnote.cells_source_notes <- function(loc, data, footnote, placement) {
 
-  stop("Footnotes cannot be applied to source notes.", call. = FALSE)
+  cli::cli_abort("Footnotes cannot be applied to source notes.")
 
   data
 }
 
 set_footnote.cells_footnotes <- function(loc, data, footnote, placement) {
 
-  stop("Footnotes cannot be applied to other footnotes.", call. = FALSE)
+  cli::cli_abort("Footnotes cannot be applied to other footnotes.")
 
   data
 }
@@ -1165,9 +1357,9 @@ set_footnote.cells_footnotes <- function(loc, data, footnote, placement) {
 #' `r man_get_image_tag(file = "man_tab_source_note_1.png")`
 #' }}
 #'
-#' @family Create or Modify Parts
+#' @family part creation/modification functions
 #' @section Function ID:
-#' 2-7
+#' 2-89
 #'
 #' @export
 tab_source_note <- function(
@@ -1314,9 +1506,9 @@ tab_source_note <- function(
 #' `r man_get_image_tag(file = "man_tab_style_3.png")`
 #' }}
 #'
-#' @family Create or Modify Parts
+#' @family part creation/modification functions
 #' @section Function ID:
-#' 2-8
+#' 2-9
 #'
 #' @seealso [cell_text()], [cell_fill()], and [cell_borders()] as helpers for
 #'   defining custom styles and [cells_body()] as one of many useful helper
@@ -1409,15 +1601,6 @@ as_style <- function(style) {
   # components together
   if (!inherits(style, "cell_styles")) {
 
-    # if (!inherits(style, "list")) {
-    #   stop("Styles should be provided exclusively by the stylizing ",
-    #        "helper functions:\n",
-    #        " * `cell_text()\n",
-    #        " * `cell_fill()\n",
-    #        " * `cell_borders()`",
-    #        call. = FALSE)
-    # }
-
     # Initialize an empty list that will be
     # populated with normalized style declarations
     final_style <- list()
@@ -1432,9 +1615,11 @@ as_style <- function(style) {
 
       } else if (!inherits(style_item, "cell_styles")) {
 
-        stop("All provided styles should be generated by stylizing ",
-             "helper functions. Style with index `", i, "` is invalid.",
-             call. = FALSE)
+        cli::cli_abort(c(
+          "All provided styles should be generated by stylizing
+          helper functions.",
+          "*" = "Style with index `{i}` is invalid."
+        ))
       }
 
       final_style <- utils::modifyList(final_style, style_item)
@@ -1577,7 +1762,6 @@ set_style.cells_body <- function(loc, data, style) {
 
   resolved <- resolve_cells_body(data = data, object = loc)
 
-  cols <- resolved$columns
   rows <- resolved$rows
 
   colnames <- resolved$colnames
@@ -1833,6 +2017,8 @@ set_style.cells_source_notes <- function(loc, data, style) {
 #'   they are separate rows that lie above the each of the groups. Setting this
 #'   to `TRUE` will structure row group labels are columns to the far left of
 #'   the table.
+#' @param stub.indent_length The width of each indentation level. By default
+#'   this is `"5px"`.
 #' @param summary_row.border.style,summary_row.border.width,summary_row.border.color
 #'   The style, width, and color properties for all horizontal borders of the
 #'   `summary_row` location.
@@ -2009,9 +2195,9 @@ set_style.cells_source_notes <- function(loc, data, style) {
 #' `r man_get_image_tag(file = "man_tab_options_6.png")`
 #' }}
 #'
-#' @family Create or Modify Parts
+#' @family part creation/modification functions
 #' @section Function ID:
-#' 2-9
+#' 2-10
 #'
 #' @export
 tab_options <- function(
@@ -2117,6 +2303,7 @@ tab_options <- function(
     stub.border.style = NULL,
     stub.border.width = NULL,
     stub.border.color = NULL,
+    stub.indent_length = NULL,
     stub_row_group.font.size = NULL,
     stub_row_group.font.weight = NULL,
     stub_row_group.text_transform = NULL,
@@ -2181,33 +2368,32 @@ tab_options <- function(
     page.footer.height = NULL
 ) {
 
-  # TODO: add helper functions to divide the options into those by location
-  # TODO: add helper functions to divide the options into those by parameter
-
   # Perform input object validation
   stop_if_not_gt(data = data)
 
   # Extract the options table from `data`
   opts_df <- dt_options_get(data = data)
 
-  arg_names <- formals(tab_options) %>% names() %>% base::setdiff("data")
+  arg_names <- base::setdiff(names(formals(tab_options)), "data")
   arg_vals <- mget(arg_names)
   arg_vals <- arg_vals[!vapply(arg_vals, FUN = is.null, FUN.VALUE = logical(1))]
-  arg_vals <- arg_vals %>% set_super_options()
+  arg_vals <- set_super_options(arg_vals = arg_vals)
 
   new_df <-
     dplyr::tibble(
-      parameter = names(arg_vals) %>% tidy_gsub(".", "_", fixed = TRUE),
-      value = unname(arg_vals)) %>%
+      parameter = tidy_gsub(names(arg_vals), ".", "_", fixed = TRUE),
+      value = unname(arg_vals)
+    ) %>%
     dplyr::left_join(
-      opts_df %>% dplyr::select(parameter, type),
+      dplyr::select(opts_df, parameter, type),
       by = "parameter"
     ) %>%
     dplyr::mutate(
       value = mapply(
         preprocess_tab_option,
         option = value, var_name = parameter, type = type,
-        SIMPLIFY = FALSE)
+        SIMPLIFY = FALSE
+      )
     ) %>%
     dplyr::select(-type)
 
@@ -2215,20 +2401,16 @@ tab_options <- function(
   # shouldn't be a problem
   opts_df <-
     dplyr::bind_rows(
-      new_df %>%
-        dplyr::inner_join(
-          opts_df %>% dplyr::select(-value),
-          by = "parameter"
-        ),
-      opts_df %>%
-        dplyr::anti_join(new_df, by = "parameter")
+      dplyr::inner_join(
+        new_df,
+        dplyr::select(opts_df, -value),
+        by = "parameter"
+      ),
+      dplyr::anti_join(opts_df, new_df, by = "parameter")
     )
 
   # Write the modified options table back to `data`
-  dt_options_set(
-    data = data,
-    options = opts_df
-  )
+  dt_options_set(data = data, options = opts_df)
 }
 
 preprocess_tab_option <- function(option, var_name, type) {
@@ -2256,20 +2438,14 @@ preprocess_tab_option <- function(option, var_name, type) {
       option
     )
 
-  # Perform checkmate assertions by `type`
+  # Perform `stopifnot()` checks by `type`
   switch(
     type,
-    logical = checkmate::assert_logical(
-      option, len = 1, any.missing = FALSE, .var.name = var_name
-    ),
-    overflow =,
-    px =,
-    value = checkmate::assert_character(
-      option, len = 1, any.missing = FALSE, .var.name = var_name
-    ),
-    values = checkmate::assert_character(
-      option, min.len = 1, any.missing = FALSE, .var.name = var_name
-    )
+    logical = stopifnot(rlang::is_scalar_logical(option), !any(is.na(option))),
+    overflow = ,
+    px = ,
+    value = stopifnot(rlang::is_scalar_character(option), !any(is.na(option))),
+    values = stopifnot(rlang::is_character(option), length(option) >= 1, !any(is.na(option)))
   )
 
   option
@@ -2284,22 +2460,29 @@ set_super_options <- function(arg_vals) {
     arg_vals$table.align <- NULL
 
     if (!(table_align_val %in% c("left", "center", "right"))) {
-      stop("The chosen option for `table.align` (`", table_align_val, "`) is invalid\n",
-           " * We can use either of `left`, `center`, or `right`.",
-           call. = FALSE)
+      cli::cli_abort(c(
+        "The chosen option for `table.align` (`{table_align_val}`) is invalid.",
+        "*" = "We can use either of \"left\", \"center\", or \"right\"."
+      ))
     }
 
-    arg_vals$table.margin.left <- arg_vals$table.margin.left %||%
-      switch(table_align_val,
-             center = "auto",
-             left = "0",
-             right = "auto")
+    arg_vals$table.margin.left <-
+      arg_vals$table.margin.left %||%
+      switch(
+        table_align_val,
+        center = "auto",
+        left = "0",
+        right = "auto"
+      )
 
-    arg_vals$table.margin.right <- arg_vals$table.margin.right %||%
-      switch(table_align_val,
-             center = "auto",
-             left = "auto",
-             right = "0")
+    arg_vals$table.margin.right <-
+      arg_vals$table.margin.right %||%
+      switch(
+        table_align_val,
+        center = "auto",
+        left = "auto",
+        right = "0"
+      )
   }
 
   arg_vals
