@@ -339,14 +339,15 @@ parse_length_str <- function(
 
   # Check for negative values and stop of `allow_negative = FALSE`
   non_na_vals <- vals[!is.na(vals)]
-  if (!allow_negative &&
-      length(non_na_vals) > 0 &&
-      any(!is.na(non_na_vals)) &&
-      is.numeric(non_na_vals) &&
-      any(non_na_vals < 0)) {
 
-    stop("Negative values supplied to widths cannot be used.",
-         call. = FALSE)
+  if (
+    !allow_negative &&
+    length(non_na_vals) > 0 &&
+    any(!is.na(non_na_vals)) &&
+    is.numeric(non_na_vals) &&
+    any(non_na_vals < 0)
+  ) {
+    cli::cli_abort("Negative values supplied to widths cannot be used.")
   }
 
   # Check for bad values and stop if necessary
@@ -355,14 +356,13 @@ parse_length_str <- function(
 
     bad_values <- lengths_vec[nzchar(lengths_vec) & is.na(vals)]
 
-    stop(
-      "Some of the values supplied cannot be interpreted:\n",
-      "* Problem values are: ",
-      str_catalog(bad_values, surround = c("\"")), "\n",
-      "* Use either of: `px`, `pt`, `in`, `cm`, `mm`, or `tw` ",
-      "(e.g., \"12px\")",
-      call. = FALSE
-    )
+    cli::cli_abort(c(
+      "Some of the values supplied cannot be interpreted.",
+      "*" = "Problem values are:
+      {str_catalog(bad_values, surround = c('\"'))}.",
+      "*" = "Use either of: `px`, `pt`, `in`, `cm`, `mm`, or `tw`
+      (e.g., \"12px\")"
+    ))
   }
 
   dplyr::tibble(value = vals, unit = units)
@@ -772,7 +772,7 @@ rtf_escape_unicode <- function(x) {
 
   # RTF wants the code points as signed 16 bit integers
   codepoints_subset_signed <- ifelse(
-    codepoints_subset > 2^15-1,
+    codepoints_subset > 2^15 - 1,
     -(bitops::bitFlip(codepoints_subset, 16) + 1), # twos complement
     codepoints_subset)
 
@@ -831,7 +831,9 @@ rtf_font_styling <- function(
     } else if (super_sub == "sub") {
       cell_super_sub <- rtf_key("sub")
     } else {
-      stop("The super_sub value must be either `\"super\"` or `\"sub\"`.")
+      cli::cli_abort(
+        "The `super_sub` value must be either \"super\" or \"sub\"."
+      )
     }
   } else {
     cell_super_sub <- ""
@@ -1118,10 +1120,6 @@ create_columns_component_rtf <- function(data) {
   column_labels_vlines_color <- dt_options_get_value(data = data, option = "column_labels_vlines_color")
   column_labels_border_lr_color <- dt_options_get_value(data = data, option = "column_labels_border_lr_color") # not used currently
 
-  # Get the column headings
-  headings_vars <- dt_boxhead_get_vars_default(data = data)
-  headings_labels <- dt_boxhead_get_vars_labels_default(data = data)
-
   # Obtain alignments for each visible column label
   col_alignment <- dt_boxhead_get_vars_align_default(data = data)
 
@@ -1215,7 +1213,6 @@ create_columns_component_rtf <- function(data) {
 
       spanner_ids_row <- spanner_ids[i, ]
       spanners_row <- spanners[i, ]
-      spanners_vars <- unique(spanner_ids_row[!is.na(spanner_ids_row)])
 
       # Replace NA values with an empty string ID
       spanner_ids_row[is.na(spanner_ids_row)] <- ""
@@ -1331,7 +1328,6 @@ create_body_component_rtf <- function(data) {
   row_group_border_right_color <- dt_options_get_value(data = data, option = "row_group_border_right_color")
   table_body_hlines_color <- dt_options_get_value(data = data, option = "table_body_hlines_color")
   table_body_vlines_color <- dt_options_get_value(data = data, option = "table_body_vlines_color")
-  table_border_bottom_color <- dt_options_get_value(data, option = "table_border_bottom_color")
 
   # Get the table width and page body width
   table_width <- dt_options_get_value(data = data, option = "table_width")
@@ -1388,9 +1384,11 @@ create_body_component_rtf <- function(data) {
   for (i in seq_len(n_rows)) {
 
     group_info <- groups_rows_df[groups_rows_df$row_start == i, c("group_id", "group_label")]
+
     if (nrow(group_info) == 0) {
       group_info <- NULL
     }
+
     group_id <- group_info[["group_id"]]
     group_label <- group_info[["group_label"]]
 
@@ -1441,9 +1439,11 @@ create_body_component_rtf <- function(data) {
               rtf_border("top", color = table_body_hlines_color, width = 10),
               rtf_border("bottom", color = table_body_hlines_color, width = 10)
             )
+
           if ("group_label" %in% stub_layout && x == 1) {
 
             if (i %in% groups_rows_df$row_start) {
+              cell_matrix[[i, x]] <- group_label
               top_bottom_borders[[2]] <- NULL
             } else if (i %in% groups_rows_df$row_end) {
               top_bottom_borders[[1]] <- NULL
@@ -1499,6 +1499,7 @@ create_body_component_rtf <- function(data) {
           widths = col_widths,
           height = 0
         )
+
     } else {
 
       body_row <-
@@ -1684,8 +1685,6 @@ create_footer_component_rtf <- function(data) {
   }
 
   # Get table components and metadata using the `data`
-  source_notes <- dt_source_notes_get(data)
-
   footnotes_tbl <- dt_footnotes_get(data = data)
   source_notes_vec <- dt_source_notes_get(data = data)
 
@@ -1702,19 +1701,14 @@ create_footer_component_rtf <- function(data) {
 
   # Obtain widths for each visible column label
   col_widths <-
-    boxh %>%
-    dplyr::filter(type %in% c("default", "stub")) %>%
+    dplyr::filter(boxh, type %in% c("default", "stub")) %>%
     dplyr::arrange(dplyr::desc(type)) %>%
     dplyr::pull(column_width) %>%
     unlist()
 
   if (is.null(col_widths)) {
 
-    n_cols <-
-      boxh %>%
-      dplyr::filter(type %in% c("default", "stub")) %>%
-      nrow()
-
+    n_cols <- nrow(dplyr::filter(boxh, type %in% c("default", "stub")))
     col_widths <- rep("100%", n_cols)
   }
 
@@ -1794,7 +1788,7 @@ create_page_footer_component_rtf <- function(data) {
   source_notes_vec <- dt_source_notes_get(data = data)
 
   # If there are no footnotes or source notes return an empty list
-  if (nrow(footnotes_tbl) == 0 && length(source_notes_vec) == 0){
+  if (nrow(footnotes_tbl) == 0 && length(source_notes_vec) == 0) {
     return(list())
   }
 
@@ -1846,8 +1840,11 @@ generate_notes_list <- function(
 
     footnote_text <-
       vapply(
-        footnote_text, FUN.VALUE = character(1), USE.NAMES = FALSE,
-        FUN = process_text, context = "rtf"
+        footnote_text,
+        FUN.VALUE = character(1),
+        USE.NAMES = FALSE,
+        FUN = process_text,
+        context = "rtf"
       )
 
     footnotes <- c()
@@ -1917,8 +1914,11 @@ get_page_body_width <- function(data) {
       option = if (page_orientation == "portrait") "page_width" else "page_height"
     )
 
-  page_margin_left_val <- dt_options_get_page_value_in_twips(data = data, option = "page_margin_left")
-  page_margin_right_val <- dt_options_get_page_value_in_twips(data = data, option = "page_margin_right")
+  page_margin_left_val <-
+    dt_options_get_page_value_in_twips(data = data, option = "page_margin_left")
+
+  page_margin_right_val <-
+    dt_options_get_page_value_in_twips(data = data, option = "page_margin_right")
 
   page_width_val - page_margin_left_val - page_margin_right_val
 }
