@@ -1,9 +1,7 @@
 # Create a table that can be used for testing
 test_tbl <-
   sza %>%
-  dplyr::filter(
-    latitude == 50 & !is.na(sza)
-  ) %>%
+  dplyr::filter(latitude == 50 & !is.na(sza)) %>%
   dplyr::group_by(month) %>%
   dplyr::summarize(min_sza = min(sza))
 
@@ -15,12 +13,8 @@ check_suggests <- function() {
 
 # Gets the HTML attr value from a single key
 selection_value <- function(html, key) {
-
   selection <- paste0("[", key, "]")
-
-  html %>%
-    rvest::html_nodes(selection) %>%
-    rvest::html_attr(key)
+  rvest::html_attr(rvest::html_nodes(html, selection), key)
 }
 
 test_that("the various color utility functions work correctly", {
@@ -274,7 +268,10 @@ test_that("the various color utility functions work correctly", {
 
   # Expect an error if 'rgba()'-format colors are passed to `normalize_colors()`
   expect_error(
-    normalize_colors(colors = c(c_name, c_hex, c_hex_a, "rgba(210,215,33,0.5)"))
+    normalize_colors(
+      colors = c(c_name, c_hex, c_hex_a, "rgba(210,215,33,0.5)"),
+      alpha = NULL
+    )
   )
 
   # Expect that the `ideal_fgnd_color()` function returns a vector containing
@@ -328,7 +325,7 @@ test_that("the various color utility functions work correctly", {
 
   # Expect that the vector of light and dark colors returned is not affected
   # by any of the colors' alpha values
-  expect_equivalent(
+  expect_equal(
     ideal_fgnd_color(
       bgnd_color = c(
         c(
