@@ -1,5 +1,3 @@
-context("Ensuring that the `cols_align*()` functions work as expected")
-
 # Create a shorter version of `mtcars`
 mtcars_short <- mtcars[1:5, ]
 
@@ -7,7 +5,8 @@ mtcars_short <- mtcars[1:5, ]
 sp500 <-
   read.csv(
     system.file("extdata", "sp500.csv", package = "gt"),
-    stringsAsFactors = FALSE)
+    stringsAsFactors = FALSE
+  )
 
 # Function to skip tests if Suggested packages not available on system
 check_suggests <- function() {
@@ -121,7 +120,7 @@ test_that("the `cols_align()` function works correctly", {
   # Expect that the `Date` column is left-formatted because
   # the column is of the `character` class
   tbl_html %>%
-    rvest::html_nodes("[class='gt_col_heading gt_columns_bottom_border gt_left']") %>%
+    rvest::html_nodes("[class='gt_col_heading gt_columns_bottom_border gt_right']") %>%
     rvest::html_text() %>%
-    expect_equal("Date")
+    expect_equal(c("Date", "Open", "High", "Low", "Close", "Volume"))
 })
