@@ -233,7 +233,7 @@ test_that("the `cols_merge_uncert()` function works correctly", {
   sep <- dt_col_merge_get(data = tbl_html) %>% .[[1]] %>% .$sep
 
   # Expect that `sep` has the `AsIs` class
-  expect_is(sep, "AsIs")
+  expect_s3_class(sep, "AsIs")
   expect_equal(as.character(sep), " +/- ")
   expect_equal(sep, I(" +/- "))
 })
@@ -264,12 +264,15 @@ test_that("the `cols_merge_uncert()` works nicely with different error bounds",
   expect_equal(
     (tbl_gt %>% render_formats_test("html"))[["value"]],
     c(
-      "34.5<span class=\"gt_two_val_uncert\">+1.8<br>&minus;2.1</span>",
-      "29.2<span class=\"gt_two_val_uncert\">+2.7<br>&minus;2.4</span>",
-      "36.3 &plusmn; 2.6", "31.6<span class=\"gt_two_val_uncert\">+NA<br>&minus;1.8</span>",
-      "28.5<span class=\"gt_two_val_uncert\">+1.6<br>&minus;NA</span>",
-      "30.9", "NA", "NA", "Inf", "30.0 &plusmn; 0.0", "32.0<span class=\"gt_two_val_uncert\">+0.0<br>&minus;0.1</span>",
-      "34.0<span class=\"gt_two_val_uncert\">+0.1<br>&minus;NaN</span>",
+      paste0("34.5<span style=\"display:inline-block;line-height:1em;text-align:right;font-size:60%;vertical-align:-0.25em;margin-left:0.1em;\">+1.8<br>", "\U02212", "2.1</span>"),
+      paste0("29.2<span style=\"display:inline-block;line-height:1em;text-align:right;font-size:60%;vertical-align:-0.25em;margin-left:0.1em;\">+2.7<br>", "\U02212", "2.4</span>"),
+      paste0("36.3 \U000B1 2.6"),
+      paste0("31.6<span style=\"display:inline-block;line-height:1em;text-align:right;font-size:60%;vertical-align:-0.25em;margin-left:0.1em;\">+NA<br>", "\U02212", "1.8</span>"),
+      paste0("28.5<span style=\"display:inline-block;line-height:1em;text-align:right;font-size:60%;vertical-align:-0.25em;margin-left:0.1em;\">+1.6<br>", "\U02212", "NA</span>"),
+      "30.9", "NA", "NA", "Inf",
+      paste0("30.0 \U000B1 0.0"),
+      paste0("32.0<span style=\"display:inline-block;line-height:1em;text-align:right;font-size:60%;vertical-align:-0.25em;margin-left:0.1em;\">+0.0<br>", "\U02212", "0.1</span>"),
+      paste0("34.0<span style=\"display:inline-block;line-height:1em;text-align:right;font-size:60%;vertical-align:-0.25em;margin-left:0.1em;\">+0.1<br>", "\U02212", "NaN</span>"),
       "NaN"
     )
   )
@@ -410,7 +413,7 @@ test_that("the `cols_merge_range()` function works correctly", {
   sep <- dt_col_merge_get(data = tbl_html) %>% .[[1]] %>% .$sep
 
   # Expect that `sep` has the `AsIs` class
-  expect_is(sep, "AsIs")
+  expect_s3_class(sep, "AsIs")
   expect_equal(as.character(sep), "--")
   expect_equal(sep, I("--"))
 
@@ -440,7 +443,7 @@ test_that("the `cols_merge_range()` function works correctly", {
   sep <- dt_col_merge_get(data = tbl_html) %>% .[[1]] %>% .$sep
 
   # Expect that `sep` has the `AsIs` class
-  expect_is(sep, "AsIs")
+  expect_s3_class(sep, "AsIs")
   expect_equal(as.character(sep), "---")
   expect_equal(sep, I("---"))
 
