@@ -1,5 +1,3 @@
-context("Ensuring that conditional formatting works as expected")
-
 # Create an input data frame four columns: two
 # character-based and two that are numeric
 data_tbl <-
@@ -40,7 +38,7 @@ test_that("the `fmt_number()` function works with conditional `rows`", {
          rows = num_1 < 1000) %>%
        render_formats_test(context = "html"))[["num_1"]],
     c("1836.23", "2763.39", "937.2900", "643.0000",
-      "212.2320", "0.0000", "&minus;23.2400"))
+      "212.2320", "0.0000", paste0("\U02212", "23.2400")))
 
   expect_equal(
     (tab %>%
@@ -61,10 +59,14 @@ test_that("the `fmt_scientific()` function works with conditional `rows`", {
          decimals = 4,
          rows = num_1 < 1000) %>%
        render_formats_test(context = "html"))[["num_1"]],
-    c("1836.23", "2763.39", "9.3729 &times; 10<sup class='gt_super'>2</sup>",
-      "6.4300 &times; 10<sup class='gt_super'>2</sup>",
-      "2.1223 &times; 10<sup class='gt_super'>2</sup>", "0.0000",
-      "&minus;2.3240 &times; 10<sup class='gt_super'>1</sup>")
+    c(
+      "1836.23", "2763.39",
+      paste0("9.3729 ", "\U000D7", " 10<sup style='font-size: 65%;'>2</sup>"),
+      paste0("6.4300 ", "\U000D7", " 10<sup style='font-size: 65%;'>2</sup>"),
+      paste0("2.1223 ", "\U000D7", " 10<sup style='font-size: 65%;'>2</sup>"),
+      "0.0000",
+      paste0("\U02212", "2.3240 ", "\U000D7", " 10<sup style='font-size: 65%;'>1</sup>")
+    )
   )
 
   expect_equal(
@@ -74,8 +76,10 @@ test_that("the `fmt_scientific()` function works with conditional `rows`", {
          decimals = 4,
          rows = char_2 %in% c("june", "july") & grepl("sa.*", char_1)) %>%
        render_formats_test(context = "html"))[["num_2"]],
-    c("3.4000 &times; 10<sup class='gt_super'>1</sup>",
-      "74", "23", "NA", "35", "NA", "NA")
+    c(
+      paste0("3.4000 ", "\U000D7", " 10<sup style='font-size: 65%;'>1</sup>"),
+      "74", "23", "NA", "35", "NA", "NA"
+    )
   )
 })
 
@@ -86,10 +90,13 @@ test_that("the `fmt_percent()` function works with conditional `rows`", {
        fmt_percent(
          columns = num_1,
          decimals = 2,
-         rows = num_1 < 1000) %>%
+         rows = num_1 < 1000
+       ) %>%
        render_formats_test(context = "html"))[["num_1"]],
-    c("1836.23", "2763.39", "93,729.00%", "64,300.00%",
-      "21,223.20%", "0.00%", "&minus;2,324.00%")
+    c(
+      "1836.23", "2763.39", "93,729.00%", "64,300.00%",
+      "21,223.20%", "0.00%", paste0("\U02212", "2,324.00%")
+    )
   )
 
   expect_equal(
@@ -112,8 +119,10 @@ test_that("the `fmt_currency()` function works with conditional `rows`", {
          currency = "USD",
          rows = num_1 < 1000) %>%
        render_formats_test(context = "html"))[["num_1"]],
-    c("1836.23", "2763.39", "$937.29", "$643.00", "$212.23",
-      "$0.00", "&minus;$23.24")
+    c(
+      "1836.23", "2763.39", "$937.29", "$643.00", "$212.23",
+      "$0.00", paste0("\U02212", "$23.24")
+    )
   )
 
   expect_equal(
@@ -136,8 +145,7 @@ test_that("the `fmt_date()` function works with conditional `rows`", {
          date_style = 2,
          rows = time == "16:45") %>%
        render_formats_test(context = "html"))[["date"]],
-    c("Sunday, October 15, 2017", "2013-02-22",
-      "2014-09-22", "2018-01-10")
+    c("Sunday, October 15, 2017", "2013-02-22", "2014-09-22", "2018-01-10")
   )
 
   expect_equal(
@@ -147,8 +155,7 @@ test_that("the `fmt_date()` function works with conditional `rows`", {
          date_style = 2,
          rows = date %in% c("2017-10-15", "2014-09-22") & grepl("^1", time)) %>%
        render_formats_test(context = "html"))[["date"]],
-    c("Sunday, October 15, 2017", "2013-02-22",
-      "2014-09-22", "2018-01-10")
+    c("Sunday, October 15, 2017", "2013-02-22", "2014-09-22", "2018-01-10")
   )
 })
 
@@ -234,7 +241,7 @@ test_that("the `sub_missing()` function works with conditional `rows`", {
          rows = num_1 <= 0
        ) %>%
        render_formats_test(context = "html"))[["num_2"]],
-    c("34", "74", "23", "NA", "35", rep("&mdash;", 2))
+    c("34", "74", "23", "NA", "35", rep("\U02014", 2))
   )
 })
 
