@@ -1,5 +1,3 @@
-context("Ensuring that the `fmt_currency()` function works as expected")
-
 test_that("the `fmt_currency()` function works correctly", {
 
   # Create an input data frame four columns: two
@@ -20,7 +18,7 @@ test_that("the `fmt_currency()` function works correctly", {
   tab <- gt(data_tbl)
 
   # Expect that the object has the correct classes
-  expect_is(tab, c("gt_tbl", "data.frame"))
+  expect_s3_class(tab, c("gt_tbl", "data.frame"))
 
   # Extract vectors from the table object for comparison
   # to the original dataset
@@ -55,8 +53,10 @@ test_that("the `fmt_currency()` function works correctly", {
     (tab %>%
        fmt_currency(columns = "num_1") %>%
        render_formats_test(context = "html"))[["num_1"]],
-    c("$1,836.23", "$2,763.39", "$937.29", "$643.00", "$212.23",
-      "$0.00", "&minus;$23.24")
+    c(
+      "$1,836.23", "$2,763.39", "$937.29", "$643.00", "$212.23",
+      "$0.00", paste0("\U02212", "$23.24")
+    )
   )
 
   # Format the `num_1` column as USD, use all other defaults;
@@ -65,8 +65,10 @@ test_that("the `fmt_currency()` function works correctly", {
     (tab %>%
        fmt_currency(columns = "num_1", currency = "USD") %>%
        render_formats_test(context = "html"))[["num_1"]],
-    c("$1,836.23", "$2,763.39", "$937.29", "$643.00", "$212.23",
-      "$0.00", "&minus;$23.24")
+    c(
+      "$1,836.23", "$2,763.39", "$937.29", "$643.00", "$212.23",
+      "$0.00", paste0("\U02212", "$23.24")
+    )
   )
 
   # Format the `num_1` column as USD to 5 decimal places, use all
@@ -75,8 +77,10 @@ test_that("the `fmt_currency()` function works correctly", {
     (tab %>%
        fmt_currency(columns = "num_1", currency = "USD", decimals = 5) %>%
        render_formats_test("html"))[["num_1"]],
-    c("$1,836.23000", "$2,763.39000", "$937.29000", "$643.00000",
-      "$212.23200", "$0.00000", "&minus;$23.24000")
+    c(
+      "$1,836.23000", "$2,763.39000", "$937.29000", "$643.00000",
+      "$212.23200", "$0.00000", paste0("\U02212", "$23.24000")
+    )
   )
 
   # Format the `num_1` column as USD, and don't include the subunits;
@@ -86,7 +90,7 @@ test_that("the `fmt_currency()` function works correctly", {
     (tab %>%
        fmt_currency(columns = "num_1", currency = "USD", use_subunits = FALSE) %>%
        render_formats_test("html"))[["num_1"]],
-    c("$1,836", "$2,763", "$937", "$643", "$212", "$0", "&minus;$23")
+    c("$1,836", "$2,763", "$937", "$643", "$212", "$0", paste0("\U02212", "$23"))
   )
 
   # Format the `num_1` column as USD, don't use digit
@@ -96,8 +100,10 @@ test_that("the `fmt_currency()` function works correctly", {
     (tab %>%
        fmt_currency(columns = "num_1", currency = "USD", use_seps = FALSE) %>%
        render_formats_test("html"))[["num_1"]],
-    c("$1836.23", "$2763.39", "$937.29", "$643.00", "$212.23",
-      "$0.00", "&minus;$23.24")
+    c(
+      "$1836.23", "$2763.39", "$937.29", "$643.00", "$212.23",
+      "$0.00", paste0("\U02212", "$23.24")
+    )
   )
 
   # Format the `num_1` column to 2 decimal places, use a single space
@@ -107,8 +113,10 @@ test_that("the `fmt_currency()` function works correctly", {
     (tab %>%
        fmt_currency(columns = "num_1", currency = "USD", sep_mark = " ") %>%
        render_formats_test("html"))[["num_1"]],
-    c("$1 836.23", "$2 763.39", "$937.29", "$643.00", "$212.23",
-      "$0.00", "&minus;$23.24")
+    c(
+      "$1 836.23", "$2 763.39", "$937.29", "$643.00", "$212.23",
+      "$0.00", paste0("\U02212", "$23.24")
+    )
   )
 
   # Format the `num_1` column as USD, use a period for the digit grouping
@@ -118,10 +126,13 @@ test_that("the `fmt_currency()` function works correctly", {
     (tab %>%
        fmt_currency(
          columns = "num_1", currency = "USD",
-         sep_mark = ".", dec_mark = ",") %>%
+         sep_mark = ".", dec_mark = ","
+       ) %>%
        render_formats_test("html"))[["num_1"]],
-    c("$1.836,23", "$2.763,39", "$937,29", "$643,00", "$212,23",
-      "$0,00", "&minus;$23,24")
+    c(
+      "$1.836,23", "$2.763,39", "$937,29", "$643,00", "$212,23",
+      "$0,00", paste0("\U02212", "$23,24")
+    )
   )
 
   # Format the `num_1` column as USD, apply parentheses to all negative
@@ -130,10 +141,13 @@ test_that("the `fmt_currency()` function works correctly", {
   expect_equal(
     (tab %>%
        fmt_currency(
-         columns = "num_1", currency = "USD", accounting = TRUE) %>%
+         columns = "num_1", currency = "USD", accounting = TRUE
+       ) %>%
        render_formats_test("html"))[["num_1"]],
-    c("$1,836.23", "$2,763.39", "$937.29", "$643.00", "$212.23",
-      "$0.00", "($23.24)")
+    c(
+      "$1,836.23", "$2,763.39", "$937.29", "$643.00",
+      "$212.23", "$0.00", "($23.24)"
+    )
   )
 
   # Format the `num_1` column as USD, apply parentheses to all negative
@@ -142,10 +156,13 @@ test_that("the `fmt_currency()` function works correctly", {
   expect_equal(
     (tab %>%
        fmt_currency(
-         columns = "num_1", currency = "USD", accounting = TRUE) %>%
+         columns = "num_1", currency = "USD", accounting = TRUE
+       ) %>%
        render_formats_test("default"))[["num_1"]],
-    c("$1,836.23", "$2,763.39", "$937.29", "$643.00", "$212.23",
-      "$0.00", "($23.24)")
+    c(
+      "$1,836.23", "$2,763.39", "$937.29", "$643.00", "$212.23",
+      "$0.00", "($23.24)"
+    )
   )
 
   # Format the `num_1` column as USD to 4 decimal places, scale all values by
@@ -155,10 +172,13 @@ test_that("the `fmt_currency()` function works correctly", {
     (tab %>%
        fmt_currency(
          columns = "num_1", currency = "USD",
-         decimals = 4, scale_by = 1/1000) %>%
+         decimals = 4, scale_by = 1/1000
+       ) %>%
        render_formats_test("html"))[["num_1"]],
-    c("$1.8362", "$2.7634", "$0.9373", "$0.6430", "$0.2122",
-      "$0.0000", "&minus;$0.0232")
+    c(
+      "$1.8362", "$2.7634", "$0.9373", "$0.6430", "$0.2122",
+      "$0.0000", paste0("\U02212", "$0.0232")
+    )
   )
 
   # Format the `num_1` column as USD, prepend and append all values by 2
@@ -167,10 +187,14 @@ test_that("the `fmt_currency()` function works correctly", {
   expect_equal(
     (tab %>%
        fmt_currency(
-         columns = "num_1", currency = "USD", pattern = "a {x} b") %>%
+         columns = "num_1", currency = "USD",
+         pattern = "a {x} b"
+       ) %>%
        render_formats_test("html"))[["num_1"]],
-    c("a $1,836.23 b", "a $2,763.39 b", "a $937.29 b", "a $643.00 b",
-      "a $212.23 b", "a $0.00 b", "a &minus;$23.24 b")
+    c(
+      "a $1,836.23 b", "a $2,763.39 b", "a $937.29 b", "a $643.00 b",
+      "a $212.23 b", "a $0.00 b", paste0("a \U02212", "$23.24 b")
+    )
   )
 
   # Format the `num_1` column as USD to 4 decimal places, scale all values
@@ -180,10 +204,13 @@ test_that("the `fmt_currency()` function works correctly", {
     (tab %>%
        fmt_currency(
          columns = "num_1", currency = "USD", decimals = 4,
-         scale_by = 1/1000, pattern = "{x}K") %>%
+         scale_by = 1/1000, pattern = "{x}K"
+       ) %>%
        render_formats_test("html"))[["num_1"]],
-    c("$1.8362K", "$2.7634K", "$0.9373K", "$0.6430K",
-      "$0.2122K", "$0.0000K", "&minus;$0.0232K")
+    c(
+      "$1.8362K", "$2.7634K", "$0.9373K", "$0.6430K",
+      "$0.2122K", "$0.0000K", paste0("\U02212", "$0.0232K")
+    )
   )
 
   # Format the `num_1` column as USD, apply the `en_US` locale and use all
@@ -191,10 +218,13 @@ test_that("the `fmt_currency()` function works correctly", {
   expect_equal(
     (tab %>%
        fmt_currency(
-         columns = "num_1", currency = "USD", locale = "en_US") %>%
+         columns = "num_1", currency = "USD", locale = "en_US"
+       ) %>%
        render_formats_test("html"))[["num_1"]],
-    c("$1,836.23", "$2,763.39", "$937.29", "$643.00",
-      "$212.23", "$0.00", "&minus;$23.24")
+    c(
+      "$1,836.23", "$2,763.39", "$937.29", "$643.00",
+      "$212.23", "$0.00", paste0("\U02212", "$23.24")
+    )
   )
 
   # Format the `num_1` column as DKK, apply the `da_DK` locale and use all
@@ -203,10 +233,13 @@ test_that("the `fmt_currency()` function works correctly", {
     (tab %>%
        fmt_currency(
          columns = "num_1", currency = "DKK", locale = "da_DK",
-         placement = "right", incl_space = TRUE) %>%
+         placement = "right", incl_space = TRUE
+       ) %>%
        render_formats_test("html"))[["num_1"]],
-    c("1.836,23 kr.", "2.763,39 kr.", "937,29 kr.", "643,00 kr.",
-      "212,23 kr.", "0,00 kr.", "&minus;23,24 kr.")
+    c(
+      "1.836,23 kr.", "2.763,39 kr.", "937,29 kr.", "643,00 kr.",
+      "212,23 kr.", "0,00 kr.", paste0("\U02212", "23,24 kr.")
+    )
   )
 
   # Format the `num_1` column as DKK, apply the `da_DK` locale and use all
@@ -217,8 +250,10 @@ test_that("the `fmt_currency()` function works correctly", {
        fmt_currency(
          columns = "num_1", currency = "DKK", locale = "da_DK") %>%
        render_formats_test("default"))[["num_1"]],
-    c("kr.1.836,23", "kr.2.763,39", "kr.937,29", "kr.643,00",
-      "kr.212,23", "kr.0,00", "-kr.23,24")
+    c(
+      "kr.1.836,23", "kr.2.763,39", "kr.937,29", "kr.643,00",
+      "kr.212,23", "kr.0,00", "-kr.23,24"
+    )
   )
 
   # Format the `num_1` column as EUR, apply the `de_AT` locale and use all
@@ -228,8 +263,10 @@ test_that("the `fmt_currency()` function works correctly", {
        fmt_currency(
          columns = "num_1", currency = "EUR", locale = "de_AT") %>%
        render_formats_test("html"))[["num_1"]],
-    c("&#8364;1 836,23", "&#8364;2 763,39", "&#8364;937,29", "&#8364;643,00",
-      "&#8364;212,23", "&#8364;0,00", "&minus;&#8364;23,24")
+    c(
+      "&#8364;1 836,23", "&#8364;2 763,39", "&#8364;937,29", "&#8364;643,00",
+      "&#8364;212,23", "&#8364;0,00", paste0("\U02212", "&#8364;23,24")
+    )
   )
 
   # Format the `num_1` column as EUR, apply the `de_AT` locale and use all
@@ -238,10 +275,13 @@ test_that("the `fmt_currency()` function works correctly", {
   expect_equal(
     (tab %>%
        fmt_currency(
-         columns = "num_1", currency = "EUR", locale = "de_AT") %>%
+         columns = "num_1", currency = "EUR", locale = "de_AT"
+       ) %>%
        render_formats_test("default"))[["num_1"]],
-    c("EUR1 836,23", "EUR2 763,39", "EUR937,29", "EUR643,00",
-      "EUR212,23", "EUR0,00", "-EUR23,24")
+    c(
+      "EUR1 836,23", "EUR2 763,39", "EUR937,29", "EUR643,00",
+      "EUR212,23", "EUR0,00", "-EUR23,24"
+    )
   )
 
   # Format the `num_1` column to 2 decimal places, apply the `et_EE`
@@ -250,10 +290,13 @@ test_that("the `fmt_currency()` function works correctly", {
   expect_equal(
     (tab %>%
        fmt_currency(
-         columns = "num_1", currency = "EUR", locale = "et_EE") %>%
+         columns = "num_1", currency = "EUR", locale = "et_EE"
+       ) %>%
        render_formats_test("html"))[["num_1"]],
-    c("&#8364;1 836,23", "&#8364;2 763,39", "&#8364;937,29", "&#8364;643,00",
-      "&#8364;212,23", "&#8364;0,00", "&minus;&#8364;23,24")
+    c(
+      "&#8364;1 836,23", "&#8364;2 763,39", "&#8364;937,29", "&#8364;643,00",
+      "&#8364;212,23", "&#8364;0,00", paste0("\U02212", "&#8364;23,24")
+    )
   )
 })
 
@@ -281,11 +324,18 @@ test_that("the `fmt_currency()` function can scale/suffix larger numbers", {
     (tab %>%
        fmt_currency(columns = "num", decimals = 2, suffixing = TRUE) %>%
        render_formats_test(context = "html"))[["num"]],
-    c("&minus;$1,800.00T", "&minus;$17.00T", "&minus;$16.00B",
-      "&minus;$150.00M", "&minus;$1.40M", "&minus;$13.00K",
-      "&minus;$1.20K", "&minus;$11.00", "$0.00", "$11.00",
-      "$1.20K", "$13.00K", "$1.40M", "$150.00M", "$16.00B",
-      "$17.00T", "$1,800.00T")
+    c(
+      paste0("\U02212", "$1,800.00T"),
+      paste0("\U02212", "$17.00T"),
+      paste0("\U02212", "$16.00B"),
+      paste0("\U02212", "$150.00M"),
+      paste0("\U02212", "$1.40M"),
+      paste0("\U02212", "$13.00K"),
+      paste0("\U02212", "$1.20K"),
+      paste0("\U02212", "$11.00"),
+      "$0.00", "$11.00", "$1.20K", "$13.00K", "$1.40M",
+      "$150.00M", "$16.00B", "$17.00T", "$1,800.00T"
+    )
   )
 
   # Format the `num` column to no decimal places, have the
@@ -295,9 +345,18 @@ test_that("the `fmt_currency()` function can scale/suffix larger numbers", {
     (tab %>%
        fmt_currency(columns = "num", decimals = 0, suffixing = TRUE) %>%
        render_formats_test(context = "html"))[["num"]],
-    c("&minus;$1,800T", "&minus;$17T", "&minus;$16B", "&minus;$150M",
-      "&minus;$1M", "&minus;$13K", "&minus;$1K", "&minus;$11", "$0",
-      "$11", "$1K", "$13K", "$1M", "$150M", "$16B", "$17T", "$1,800T")
+    c(
+      paste0("\U02212", "$1,800T"),
+      paste0("\U02212", "$17T"),
+      paste0("\U02212", "$16B"),
+      paste0("\U02212", "$150M"),
+      paste0("\U02212", "$1M"),
+      paste0("\U02212", "$13K"),
+      paste0("\U02212", "$1K"),
+      paste0("\U02212", "$11"),
+      "$0", "$11", "$1K", "$13K", "$1M",
+      "$150M", "$16B", "$17T", "$1,800T"
+    )
   )
 
   # Format the `num` column to 2 decimal places, have the
@@ -307,12 +366,21 @@ test_that("the `fmt_currency()` function can scale/suffix larger numbers", {
     (tab %>%
        fmt_currency(
          columns = "num", decimals = 2,
-         suffixing = c("k", "Mn", "Bn", "Tr")) %>%
+         suffixing = c("k", "Mn", "Bn", "Tr")
+       ) %>%
        render_formats_test(context = "html"))[["num"]],
-    c("&minus;$1,800.00Tr", "&minus;$17.00Tr", "&minus;$16.00Bn",
-      "&minus;$150.00Mn", "&minus;$1.40Mn", "&minus;$13.00k", "&minus;$1.20k",
-      "&minus;$11.00", "$0.00", "$11.00", "$1.20k", "$13.00k", "$1.40Mn",
-      "$150.00Mn", "$16.00Bn", "$17.00Tr", "$1,800.00Tr")
+    c(
+      paste0("\U02212", "$1,800.00Tr"),
+      paste0("\U02212", "$17.00Tr"),
+      paste0("\U02212", "$16.00Bn"),
+      paste0("\U02212", "$150.00Mn"),
+      paste0("\U02212", "$1.40Mn"),
+      paste0("\U02212", "$13.00k"),
+      paste0("\U02212", "$1.20k"),
+      paste0("\U02212", "$11.00"),
+      "$0.00", "$11.00", "$1.20k", "$13.00k", "$1.40Mn",
+      "$150.00Mn", "$16.00Bn", "$17.00Tr", "$1,800.00Tr"
+    )
   )
 
   # Format the `num` column to 2 decimal places, have the
@@ -322,15 +390,23 @@ test_that("the `fmt_currency()` function can scale/suffix larger numbers", {
     (tab %>%
        fmt_currency(
          columns = "num", decimals = 2, currency = "EUR", locale = "de_DE",
-         suffixing = c(NA, "Mio.", "Mia.", NA)) %>%
+         suffixing = c(NA, "Mio.", "Mia.", NA)
+       ) %>%
        render_formats_test(context = "html"))[["num"]],
-    c("&minus;&#8364;1.800.000,00Mia.", "&minus;&#8364;17.000,00Mia.",
-      "&minus;&#8364;16,00Mia.", "&minus;&#8364;150,00Mio.",
-      "&minus;&#8364;1,40Mio.", "&minus;&#8364;13.000,00",
-      "&minus;&#8364;1.200,00", "&minus;&#8364;11,00", "&#8364;0,00",
+    c(
+      paste0("\U02212", "&#8364;1.800.000,00Mia."),
+      paste0("\U02212", "&#8364;17.000,00Mia."),
+      paste0("\U02212", "&#8364;16,00Mia."),
+      paste0("\U02212", "&#8364;150,00Mio."),
+      paste0("\U02212", "&#8364;1,40Mio."),
+      paste0("\U02212", "&#8364;13.000,00"),
+      paste0("\U02212", "&#8364;1.200,00"),
+      paste0("\U02212", "&#8364;11,00"),
+      "&#8364;0,00",
       "&#8364;11,00", "&#8364;1.200,00", "&#8364;13.000,00", "&#8364;1,40Mio.",
       "&#8364;150,00Mio.", "&#8364;16,00Mia.", "&#8364;17.000,00Mia.",
-      "&#8364;1.800.000,00Mia.")
+      "&#8364;1.800.000,00Mia."
+    )
   )
 
   # Format the `num` column to 2 decimal places, have the
@@ -339,13 +415,21 @@ test_that("the `fmt_currency()` function can scale/suffix larger numbers", {
     (tab %>%
        fmt_currency(
          columns = "num", decimals = 2,
-         suffixing = c("K", NA, "Bn", NA, "Qa", NA, NA)) %>%
+         suffixing = c("K", NA, "Bn", NA, "Qa", NA, NA)
+       ) %>%
        render_formats_test(context = "html"))[["num"]],
-    c("&minus;$1.80Qa", "&minus;$17,000.00Bn", "&minus;$16.00Bn",
-      "&minus;$150,000.00K", "&minus;$1,400.00K", "&minus;$13.00K",
-      "&minus;$1.20K", "&minus;$11.00", "$0.00", "$11.00", "$1.20K",
-      "$13.00K", "$1,400.00K", "$150,000.00K", "$16.00Bn",
-      "$17,000.00Bn", "$1.80Qa")
+    c(
+      paste0("\U02212", "$1.80Qa"),
+      paste0("\U02212", "$17,000.00Bn"),
+      paste0("\U02212", "$16.00Bn"),
+      paste0("\U02212", "$150,000.00K"),
+      paste0("\U02212", "$1,400.00K"),
+      paste0("\U02212", "$13.00K"),
+      paste0("\U02212", "$1.20K"),
+      paste0("\U02212", "$11.00"),
+      "$0.00", "$11.00", "$1.20K", "$13.00K", "$1,400.00K",
+      "$150,000.00K", "$16.00Bn", "$17,000.00Bn", "$1.80Qa"
+    )
   )
 
   # Format the `num` column to 2 decimal places, have the
@@ -355,14 +439,22 @@ test_that("the `fmt_currency()` function can scale/suffix larger numbers", {
     (tab %>%
        fmt_currency(
          columns = "num", decimals = 2,
-         suffixing = FALSE) %>%
+         suffixing = FALSE
+       ) %>%
        render_formats_test(context = "html"))[["num"]],
-    c( "&minus;$1,800,000,000,000,000.00", "&minus;$17,000,000,000,000.00",
-       "&minus;$16,000,000,000.00", "&minus;$150,000,000.00",
-       "&minus;$1,400,000.00", "&minus;$13,000.00", "&minus;$1,200.00",
-       "&minus;$11.00", "$0.00", "$11.00", "$1,200.00", "$13,000.00",
-       "$1,400,000.00", "$150,000,000.00", "$16,000,000,000.00",
-       "$17,000,000,000,000.00", "$1,800,000,000,000,000.00")
+    c(
+      paste0("\U02212", "$1,800,000,000,000,000.00"),
+      paste0("\U02212", "$17,000,000,000,000.00"),
+      paste0("\U02212", "$16,000,000,000.00"),
+      paste0("\U02212", "$150,000,000.00"),
+      paste0("\U02212", "$1,400,000.00"),
+      paste0("\U02212", "$13,000.00"),
+      paste0("\U02212", "$1,200.00"),
+      paste0("\U02212", "$11.00"),
+      "$0.00", "$11.00", "$1,200.00", "$13,000.00",
+      "$1,400,000.00", "$150,000,000.00", "$16,000,000,000.00",
+      "$17,000,000,000,000.00", "$1,800,000,000,000,000.00"
+    )
   )
 
   # Expect an error if any vector length other than
@@ -447,7 +539,7 @@ test_that("the `currency()` helper function works correctly", {
       is.list()
   )
 
-  expect_is(
+  expect_s3_class(
     currency(html = "&#8383;", latex = "BTC", default = "BTC"),
     "gt_currency"
   )
@@ -470,7 +562,7 @@ test_that("the `currency()` helper function works correctly", {
   single_default_currency <- currency("BTC")
 
   single_default_currency %>% is.list() %>% expect_true()
-  single_default_currency %>% expect_is("gt_currency")
+  single_default_currency %>% expect_s3_class("gt_currency")
   single_default_currency %>% length() %>% expect_equal(1)
   single_default_currency %>% names() %>% expect_equal("default")
   single_default_currency[[1]] %>% expect_equal("BTC")
@@ -515,11 +607,14 @@ test_that("the `currency()` helper function works correctly", {
        fmt_currency(
          columns = "num_1",
          currency = currency(html = "&#8383;", latex = "BTC", default = "BTC"),
-         decimals = 4) %>%
+         decimals = 4
+       ) %>%
        render_formats_test(context = "html"))[["num_1"]],
-    c("&#8383;1,836.2300", "&#8383;2,763.3900", "&#8383;937.2900",
+    c(
+      "&#8383;1,836.2300", "&#8383;2,763.3900", "&#8383;937.2900",
       "&#8383;643.0000", "&#8383;212.2320", "&#8383;0.0000",
-      "&minus;&#8383;23.2400")
+      paste0("\U02212", "&#8383;23.2400")
+    )
   )
 
   # Format the `num_1` column using the `currency()` helper function (not
@@ -530,12 +625,15 @@ test_that("the `currency()` helper function works correctly", {
        fmt_currency(
          columns = "num_1",
          currency = currency(
-           html = "&#8383;", latex = "BTC", default = "BTC")
+           html = "&#8383;", latex = "BTC", default = "BTC"
+         )
        ) %>%
        render_formats_test(context = "html"))[["num_1"]],
-    c("&#8383;1,836.23", "&#8383;2,763.39", "&#8383;937.29",
+    c(
+      "&#8383;1,836.23", "&#8383;2,763.39", "&#8383;937.29",
       "&#8383;643.00", "&#8383;212.23", "&#8383;0.00",
-      "&minus;&#8383;23.24")
+      paste0("\U02212", "&#8383;23.24")
+    )
   )
 
   # Format the `num_1` column using the `currency()` helper function;
@@ -545,11 +643,15 @@ test_that("the `currency()` helper function works correctly", {
        fmt_currency(
          columns = "num_1",
          currency = currency(html = "&#8383;", latex = "BTC", default = "BTC"),
-         decimals = 4) %>%
+         decimals = 4
+       ) %>%
        render_formats_test(context = "latex"))[["num_1"]],
-    c("$\\text{BTC}1,836.2300$", "$\\text{BTC}2,763.3900$",
+    c(
+      "$\\text{BTC}1,836.2300$", "$\\text{BTC}2,763.3900$",
       "$\\text{BTC}937.2900$", "$\\text{BTC}643.0000$",
-      "$\\text{BTC}212.2320$", "$\\text{BTC}0.0000$", "$-\\text{BTC}23.2400$")
+      "$\\text{BTC}212.2320$", "$\\text{BTC}0.0000$",
+      "$-\\text{BTC}23.2400$"
+    )
   )
 
   # Format the `num_1` column using the `currency()` helper function;
@@ -559,10 +661,13 @@ test_that("the `currency()` helper function works correctly", {
        fmt_currency(
          columns = "num_1",
          currency = currency(latex = "BTC", default = "bt"),
-         decimals = 2) %>%
+         decimals = 2
+       ) %>%
        render_formats_test(context = "html"))[["num_1"]],
-    c("bt1,836.23", "bt2,763.39", "bt937.29", "bt643.00", "bt212.23", "bt0.00",
-      "&minus;bt23.24")
+    c(
+      "bt1,836.23", "bt2,763.39", "bt937.29", "bt643.00",
+      "bt212.23", "bt0.00", paste0("\U02212", "bt23.24")
+    )
   )
 
   # Format the `num_1` column using the `currency()` helper function;
@@ -573,11 +678,15 @@ test_that("the `currency()` helper function works correctly", {
        fmt_currency(
          columns = "num_1",
          currency = currency(html = "HKD", latex = "HK$", default = "hkd"),
-         decimals = 2) %>%
+         decimals = 2
+       ) %>%
        render_formats_test(context = "latex"))[["num_1"]],
-    c("$\\text{HK\\$}1,836.23$", "$\\text{HK\\$}2,763.39$",
+    c(
+      "$\\text{HK\\$}1,836.23$", "$\\text{HK\\$}2,763.39$",
       "$\\text{HK\\$}937.29$", "$\\text{HK\\$}643.00$",
-      "$\\text{HK\\$}212.23$", "$\\text{HK\\$}0.00$", "$-\\text{HK\\$}23.24$")
+      "$\\text{HK\\$}212.23$", "$\\text{HK\\$}0.00$",
+      "$-\\text{HK\\$}23.24$"
+    )
   )
 })
 
@@ -626,13 +735,21 @@ test_that("the `fmt_currency()` fn can render in the Indian numbering system", {
        fmt_currency(columns = num, currency = "INR", system = "ind") %>%
        render_formats_test(context = "html"))[["num"]],
     c(
-      "&#8377;50,00,000.01", "&#8377;1,000.00", "&#8377;10.00", "&#8377;12,345.00",
-      "&#8377;1,234.50", "&#8377;123.45", "&#8377;1.23", "&#8377;0.12",
-      "&#8377;25,83,063.23", "&#8377;1,53,56,74,223.33", "&#8377;6,42,56,48,25,73,36,228.00",
-      "&minus;&#8377;50,00,00,000.00", "&minus;&#8377;1,000.00", "&minus;&#8377;10.00",
-      "&minus;&#8377;12,345.00", "&minus;&#8377;1,234.50", "&minus;&#8377;123.45",
-      "&minus;&#8377;1.23", "&minus;&#8377;0.12", "&minus;&#8377;0.00",
-      "&#8377;0.00", "NA", "&#8377;Inf", "&minus;&#8377;Inf"
+      "&#8377;50,00,000.01", "&#8377;1,000.00", "&#8377;10.00",
+      "&#8377;12,345.00", "&#8377;1,234.50", "&#8377;123.45", "&#8377;1.23",
+      "&#8377;0.12", "&#8377;25,83,063.23", "&#8377;1,53,56,74,223.33",
+      "&#8377;6,42,56,48,25,73,36,228.00",
+      paste0("\U02212", "&#8377;50,00,00,000.00"),
+      paste0("\U02212", "&#8377;1,000.00"),
+      paste0("\U02212", "&#8377;10.00"),
+      paste0("\U02212", "&#8377;12,345.00"),
+      paste0("\U02212", "&#8377;1,234.50"),
+      paste0("\U02212", "&#8377;123.45"),
+      paste0("\U02212", "&#8377;1.23"),
+      paste0("\U02212", "&#8377;0.12"),
+      paste0("\U02212", "&#8377;0.00"),
+      "&#8377;0.00", "NA", "&#8377;Inf",
+      paste0("\U02212", "&#8377;Inf")
     )
   )
 
@@ -640,74 +757,120 @@ test_that("the `fmt_currency()` fn can render in the Indian numbering system", {
   # each number's sign to always be present
   expect_equal(
     (tab %>%
-       fmt_currency(columns = num, currency = "INR", force_sign = TRUE, system = "ind") %>%
+       fmt_currency(
+         columns = num, currency = "INR",
+         force_sign = TRUE, system = "ind"
+       ) %>%
        render_formats_test(context = "html"))[["num"]],
     c(
       "+&#8377;50,00,000.01", "+&#8377;1,000.00", "+&#8377;10.00",
       "+&#8377;12,345.00", "+&#8377;1,234.50", "+&#8377;123.45", "+&#8377;1.23",
       "+&#8377;0.12", "+&#8377;25,83,063.23", "+&#8377;1,53,56,74,223.33",
-      "+&#8377;6,42,56,48,25,73,36,228.00", "&minus;&#8377;50,00,00,000.00",
-      "&minus;&#8377;1,000.00", "&minus;&#8377;10.00", "&minus;&#8377;12,345.00",
-      "&minus;&#8377;1,234.50", "&minus;&#8377;123.45", "&minus;&#8377;1.23",
-      "&minus;&#8377;0.12", "&minus;&#8377;0.00", "&#8377;0.00", "NA",
-      "+&#8377;Inf", "&minus;&#8377;Inf"
+      "+&#8377;6,42,56,48,25,73,36,228.00",
+      paste0("\U02212", "&#8377;50,00,00,000.00"),
+      paste0("\U02212", "&#8377;1,000.00"),
+      paste0("\U02212", "&#8377;10.00"),
+      paste0("\U02212", "&#8377;12,345.00"),
+      paste0("\U02212", "&#8377;1,234.50"),
+      paste0("\U02212", "&#8377;123.45"),
+      paste0("\U02212", "&#8377;1.23"),
+      paste0("\U02212", "&#8377;0.12"),
+      paste0("\U02212", "&#8377;0.00"),
+      "&#8377;0.00", "NA", "+&#8377;Inf",
+      paste0("\U02212", "&#8377;Inf")
     )
   )
 
   # Format the `num` column and use appropriate suffixes
   expect_equal(
     (tab %>%
-       fmt_currency(columns = num, currency = "INR", suffixing = TRUE, system = "ind") %>%
+       fmt_currency(
+         columns = num, currency = "INR",
+         suffixing = TRUE, system = "ind"
+       ) %>%
        render_formats_test(context = "html"))[["num"]],
     c(
       "&#8377;50.00 Lac", "&#8377;1,000.00", "&#8377;10.00", "&#8377;12,345.00",
       "&#8377;1,234.50", "&#8377;123.45", "&#8377;1.23", "&#8377;0.12",
       "&#8377;25.83 Lac", "&#8377;153.57 Cr", "&#8377;64,25,64,825.73 Cr",
-      "&minus;&#8377;50.00 Cr", "&minus;&#8377;1,000.00", "&minus;&#8377;10.00",
-      "&minus;&#8377;12,345.00", "&minus;&#8377;1,234.50", "&minus;&#8377;123.45",
-      "&minus;&#8377;1.23", "&minus;&#8377;0.12", "&minus;&#8377;0.00",
-      "&#8377;0.00", "NA", "&#8377;Inf Cr", "&minus;&#8377;Inf Cr"
+      paste0("\U02212", "&#8377;50.00 Cr"),
+      paste0("\U02212", "&#8377;1,000.00"),
+      paste0("\U02212", "&#8377;10.00"),
+      paste0("\U02212", "&#8377;12,345.00"),
+      paste0("\U02212", "&#8377;1,234.50"),
+      paste0("\U02212", "&#8377;123.45"),
+      paste0("\U02212", "&#8377;1.23"),
+      paste0("\U02212", "&#8377;0.12"),
+      paste0("\U02212", "&#8377;0.00"),
+      "&#8377;0.00", "NA", "&#8377;Inf Cr",
+      paste0("\U02212", "&#8377;Inf Cr")
     )
   )
   expect_equal(
     (tab %>%
-       fmt_currency(columns = num, currency = "INR", suffixing = c("K", "Lacs", "Crores"), system = "ind") %>%
+       fmt_currency(
+         columns = num, currency = "INR",
+         suffixing = c("K", "Lacs", "Crores"), system = "ind"
+       ) %>%
        render_formats_test(context = "html"))[["num"]],
     c(
       "&#8377;50.00 Lacs", "&#8377;1.00 K", "&#8377;10.00", "&#8377;12.35 K",
       "&#8377;1.23 K", "&#8377;123.45", "&#8377;1.23", "&#8377;0.12",
-      "&#8377;25.83 Lacs", "&#8377;153.57 Crores", "&#8377;64,25,64,825.73 Crores",
-      "&minus;&#8377;50.00 Crores", "&minus;&#8377;1.00 K", "&minus;&#8377;10.00",
-      "&minus;&#8377;12.35 K", "&minus;&#8377;1.23 K", "&minus;&#8377;123.45",
-      "&minus;&#8377;1.23", "&minus;&#8377;0.12", "&minus;&#8377;0.00",
-      "&#8377;0.00", "NA", "&#8377;Inf Crores", "&minus;&#8377;Inf Crores"
+      "&#8377;25.83 Lacs", "&#8377;153.57 Crores",
+      "&#8377;64,25,64,825.73 Crores",
+      paste0("\U02212", "&#8377;50.00 Crores"),
+      paste0("\U02212", "&#8377;1.00 K"),
+      paste0("\U02212", "&#8377;10.00"),
+      paste0("\U02212", "&#8377;12.35 K"),
+      paste0("\U02212", "&#8377;1.23 K"),
+      paste0("\U02212", "&#8377;123.45"),
+      paste0("\U02212", "&#8377;1.23"),
+      paste0("\U02212", "&#8377;0.12"),
+      paste0("\U02212", "&#8377;0.00"),
+      "&#8377;0.00", "NA", "&#8377;Inf Crores",
+      paste0("\U02212", "&#8377;Inf Crores")
     )
   )
   expect_equal(
     (tab %>%
-       fmt_currency(columns = num, currency = "INR", suffixing = c(NA, "Lacs", NA), system = "ind") %>%
+       fmt_currency(
+         columns = num, currency = "INR",
+         suffixing = c(NA, "Lacs", NA), system = "ind"
+       ) %>%
        render_formats_test(context = "html"))[["num"]],
     c(
-      "&#8377;50.00 Lacs", "&#8377;1,000.00", "&#8377;10.00", "&#8377;12,345.00",
-      "&#8377;1,234.50", "&#8377;123.45", "&#8377;1.23", "&#8377;0.12",
-      "&#8377;25.83 Lacs", "&#8377;15,356.74 Lacs", "&#8377;64,25,64,82,573.36 Lacs",
-      "&minus;&#8377;5,000.00 Lacs", "&minus;&#8377;1,000.00", "&minus;&#8377;10.00",
-      "&minus;&#8377;12,345.00", "&minus;&#8377;1,234.50", "&minus;&#8377;123.45",
-      "&minus;&#8377;1.23", "&minus;&#8377;0.12", "&minus;&#8377;0.00",
-      "&#8377;0.00", "NA", "&#8377;Inf Lacs", "&minus;&#8377;Inf Lacs"
+      "&#8377;50.00 Lacs", "&#8377;1,000.00", "&#8377;10.00",
+      "&#8377;12,345.00", "&#8377;1,234.50", "&#8377;123.45", "&#8377;1.23",
+      "&#8377;0.12", "&#8377;25.83 Lacs", "&#8377;15,356.74 Lacs",
+      "&#8377;64,25,64,82,573.36 Lacs",
+      paste0("\U02212", "&#8377;5,000.00 Lacs"),
+      paste0("\U02212", "&#8377;1,000.00"),
+      paste0("\U02212", "&#8377;10.00"),
+      paste0("\U02212", "&#8377;12,345.00"),
+      paste0("\U02212", "&#8377;1,234.50"),
+      paste0("\U02212", "&#8377;123.45"),
+      paste0("\U02212", "&#8377;1.23"),
+      paste0("\U02212", "&#8377;0.12"),
+      paste0("\U02212", "&#8377;0.00"),
+      "&#8377;0.00", "NA", "&#8377;Inf Lacs",
+      paste0("\U02212", "&#8377;Inf Lacs")
     )
   )
   expect_equal(
     (tab %>%
-       fmt_currency(columns = num, currency = "INR", suffixing = TRUE, accounting = TRUE, system = "ind") %>%
+       fmt_currency(
+         columns = num, currency = "INR",
+         suffixing = TRUE, accounting = TRUE, system = "ind"
+       ) %>%
        render_formats_test(context = "html"))[["num"]],
     c(
-      "&#8377;50.00 Lac", "&#8377;1,000.00", "&#8377;10.00", "&#8377;12,345.00",
-      "&#8377;1,234.50", "&#8377;123.45", "&#8377;1.23", "&#8377;0.12",
-      "&#8377;25.83 Lac", "&#8377;153.57 Cr", "&#8377;64,25,64,825.73 Cr",
-      "(&#8377;50.00) Cr", "(&#8377;1,000.00)", "(&#8377;10.00)", "(&#8377;12,345.00)",
-      "(&#8377;1,234.50)", "(&#8377;123.45)", "(&#8377;1.23)", "(&#8377;0.12)",
-      "(&#8377;0.00)", "&#8377;0.00", "NA", "&#8377;Inf Cr", "(&#8377;Inf) Cr"
+      "&#8377;50.00 Lac", "&#8377;1,000.00", "&#8377;10.00",
+      "&#8377;12,345.00", "&#8377;1,234.50", "&#8377;123.45",
+      "&#8377;1.23", "&#8377;0.12", "&#8377;25.83 Lac", "&#8377;153.57 Cr",
+      "&#8377;64,25,64,825.73 Cr", "(&#8377;50.00) Cr", "(&#8377;1,000.00)",
+      "(&#8377;10.00)", "(&#8377;12,345.00)", "(&#8377;1,234.50)",
+      "(&#8377;123.45)", "(&#8377;1.23)", "(&#8377;0.12)", "(&#8377;0.00)",
+      "&#8377;0.00", "NA", "&#8377;Inf Cr", "(&#8377;Inf) Cr"
     )
   )
   expect_warning(
