@@ -17,7 +17,7 @@ test_that("the `fmt_integer()` function works correctly in the HTML context", {
   tab <- gt(data_tbl)
 
   # Expect that the object has the correct classes
-  expect_is(tab, c("gt_tbl", "data.frame"))
+  expect_s3_class(tab, c("gt_tbl", "data.frame"))
 
   # Extract vectors from the table object for comparison
   # to the original dataset
@@ -52,7 +52,7 @@ test_that("the `fmt_integer()` function works correctly in the HTML context", {
     (tab %>%
        fmt_integer(columns = num_1) %>%
        render_formats_test(context = "html"))[["num_1"]],
-    c("1,836", "2,763", "937", "643", "212", "0", "&minus;23")
+    c("1,836", "2,763", "937", "643", "212", "0", paste0("\U02212", "23"))
   )
 
   # Format the `num_1` column, don't use digit
@@ -61,7 +61,7 @@ test_that("the `fmt_integer()` function works correctly in the HTML context", {
     (tab %>%
        fmt_integer(columns = num_1, use_seps = FALSE) %>%
        render_formats_test("html"))[["num_1"]],
-    c("1836", "2763", "937", "643", "212", "0", "&minus;23")
+    c("1836", "2763", "937", "643", "212", "0", paste0("\U02212", "23"))
   )
 
   # Format the `num_1` column, use a single space
@@ -70,7 +70,7 @@ test_that("the `fmt_integer()` function works correctly in the HTML context", {
     (tab %>%
        fmt_integer(columns = num_1, sep_mark = " ") %>%
        render_formats_test("html"))[["num_1"]],
-    c("1 836", "2 763", "937", "643", "212", "0", "&minus;23")
+    c("1 836", "2 763", "937", "643", "212", "0", paste0("\U02212", "23"))
   )
 
   # Format the `num_1` column, use a period for the
@@ -79,7 +79,7 @@ test_that("the `fmt_integer()` function works correctly in the HTML context", {
     (tab %>%
        fmt_integer(columns = num_1, sep_mark = ".") %>%
        render_formats_test("html"))[["num_1"]],
-    c("1.836", "2.763", "937", "643", "212", "0", "&minus;23")
+    c("1.836", "2.763", "937", "643", "212", "0", paste0("\U02212", "23"))
   )
 
   # Format the `num_1` column, scale all values by
@@ -97,8 +97,10 @@ test_that("the `fmt_integer()` function works correctly in the HTML context", {
     (tab %>%
        fmt_integer(columns = num_1, pattern = "a {x} b") %>%
        render_formats_test("html"))[["num_1"]],
-    c("a 1,836 b", "a 2,763 b", "a 937 b", "a 643 b", "a 212 b",
-      "a 0 b", "a &minus;23 b")
+    c(
+      "a 1,836 b", "a 2,763 b", "a 937 b", "a 643 b", "a 212 b",
+      "a 0 b", paste0("a \U02212", "23 b")
+    )
   )
 
   # Format the `num_1` column, scale all values
@@ -135,7 +137,7 @@ test_that("the `fmt_integer()` function works correctly in the HTML context", {
        fmt_integer(
          columns = num_1, force_sign = TRUE) %>%
        render_formats_test("html"))[["num_1"]],
-    c("+1,836", "+2,763", "+937", "+643", "+212", "0", "&minus;23")
+    c("+1,836", "+2,763", "+937", "+643", "+212", "0", paste0("\U02212", "23"))
   )
 
   # Expect that using `force_sign = TRUE` with `accounting = TRUE`
@@ -158,7 +160,7 @@ test_that("the `fmt_integer()` function works correctly in the HTML context", {
        fmt_integer(
          columns = num_1, pattern = "*{x}*", force_sign = TRUE) %>%
        render_formats_test("html"))[["num_1"]],
-    c("*+1,836*", "*+2,763*", "*+937*", "*+643*", "*+212*", "*0*", "*&minus;23*")
+    c("*+1,836*", "*+2,763*", "*+937*", "*+643*", "*+212*", "*0*", paste0("*\U02212", "23*"))
   )
 
   # Format the `num_1`, apply the `en_US`
@@ -167,7 +169,7 @@ test_that("the `fmt_integer()` function works correctly in the HTML context", {
     (tab %>%
        fmt_integer(columns = num_1, locale = "en_US") %>%
        render_formats_test("html"))[["num_1"]],
-    c("1,836", "2,763", "937", "643", "212", "0", "&minus;23")
+    c("1,836", "2,763", "937", "643", "212", "0", paste0("\U02212", "23"))
   )
 
   # Format the `num_1` column, apply the `da_DK`
@@ -176,7 +178,7 @@ test_that("the `fmt_integer()` function works correctly in the HTML context", {
     (tab %>%
        fmt_integer(columns = num_1, locale = "da_DK") %>%
        render_formats_test("html"))[["num_1"]],
-    c("1.836", "2.763", "937", "643", "212", "0", "&minus;23")
+    c("1.836", "2.763", "937", "643", "212", "0", paste0("\U02212", "23"))
   )
 
   # Expect that a column with NAs will work fine with `fmt_integer()`,
@@ -247,9 +249,15 @@ test_that("the `fmt_integer()` function can scale/suffix larger numbers", {
        fmt_integer(columns = num, suffixing = TRUE) %>%
        render_formats_test(context = "html"))[["num"]],
     c(
-      "&minus;1,800T", "&minus;17T", "&minus;16B", "&minus;150M",
-      "&minus;1M", "&minus;13K", "&minus;1K", "&minus;11", "0", "11",
-      "1K", "13K", "1M", "150M", "16B", "17T", "1,800T"
+      paste0("\U02212", "1,800T"),
+      paste0("\U02212", "17T"),
+      paste0("\U02212", "16B"),
+      paste0("\U02212", "150M"),
+      paste0("\U02212", "1M"),
+      paste0("\U02212", "13K"),
+      paste0("\U02212", "1K"),
+      paste0("\U02212", "11"),
+      "0", "11", "1K", "13K", "1M", "150M", "16B", "17T", "1,800T"
     )
   )
 
@@ -262,9 +270,15 @@ test_that("the `fmt_integer()` function can scale/suffix larger numbers", {
          suffixing = c("k", "Mn", "Bn", "Tr")) %>%
        render_formats_test(context = "html"))[["num"]],
     c(
-      "&minus;1,800Tr", "&minus;17Tr", "&minus;16Bn", "&minus;150Mn",
-      "&minus;1Mn", "&minus;13k", "&minus;1k", "&minus;11", "0", "11",
-      "1k", "13k", "1Mn", "150Mn", "16Bn", "17Tr", "1,800Tr"
+      paste0("\U02212", "1,800Tr"),
+      paste0("\U02212", "17Tr"),
+      paste0("\U02212", "16Bn"),
+      paste0("\U02212", "150Mn"),
+      paste0("\U02212", "1Mn"),
+      paste0("\U02212", "13k"),
+      paste0("\U02212", "1k"),
+      paste0("\U02212", "11"),
+      "0", "11", "1k", "13k", "1Mn", "150Mn", "16Bn", "17Tr", "1,800Tr"
     )
   )
 
@@ -277,9 +291,15 @@ test_that("the `fmt_integer()` function can scale/suffix larger numbers", {
          suffixing = c(NA, "Mio.", "Mia.", NA)) %>%
        render_formats_test(context = "html"))[["num"]],
     c(
-      "&minus;1,800,000Mia.", "&minus;17,000Mia.", "&minus;16Mia.",
-      "&minus;150Mio.", "&minus;1Mio.", "&minus;13,000", "&minus;1,200",
-      "&minus;11", "0", "11", "1,200", "13,000", "1Mio.", "150Mio.",
+      paste0("\U02212", "1,800,000Mia."),
+      paste0("\U02212", "17,000Mia."),
+      paste0("\U02212", "16Mia."),
+      paste0("\U02212", "150Mio."),
+      paste0("\U02212", "1Mio."),
+      paste0("\U02212", "13,000"),
+      paste0("\U02212", "1,200"),
+      paste0("\U02212", "11"),
+      "0", "11", "1,200", "13,000", "1Mio.", "150Mio.",
       "16Mia.", "17,000Mia.", "1,800,000Mia."
     )
   )
@@ -371,9 +391,15 @@ test_that("the `fmt_integer()` fn can render in the Indian numbering system", {
     c(
       "50,00,000", "1,000", "10", "12,345", "1,234", "123", "1",
       "0", "25,83,063", "1,53,56,74,223", "6,42,56,48,25,73,36,228",
-      "&minus;50,00,00,000", "&minus;1,000", "&minus;10", "&minus;12,345",
-      "&minus;1,234", "&minus;123", "&minus;1", "0", "0", "0", "NA",
-      " Inf", "&minus;Inf"
+      paste0("\U02212", "50,00,00,000"),
+      paste0("\U02212", "1,000"),
+      paste0("\U02212", "10"),
+      paste0("\U02212", "12,345"),
+      paste0("\U02212", "1,234"),
+      paste0("\U02212", "123"),
+      paste0("\U02212", "1"),
+      "0", "0", "0", "NA", " Inf",
+      paste0("\U02212", "Inf")
     )
   )
 
@@ -386,9 +412,15 @@ test_that("the `fmt_integer()` fn can render in the Indian numbering system", {
     c(
       "+50,00,000", "+1,000", "+10", "+12,345", "+1,234", "+123",
       "+1", "+0", "+25,83,063", "+1,53,56,74,223", "+6,42,56,48,25,73,36,228",
-      "&minus;50,00,00,000", "&minus;1,000", "&minus;10", "&minus;12,345",
-      "&minus;1,234", "&minus;123", "&minus;1", "0", "0", "0", "NA",
-      "+ Inf", "&minus;Inf"
+      paste0("\U02212", "50,00,00,000"),
+      paste0("\U02212", "1,000"),
+      paste0("\U02212", "10"),
+      paste0("\U02212", "12,345"),
+      paste0("\U02212", "1,234"),
+      paste0("\U02212", "123"),
+      paste0("\U02212", "1"),
+      "0", "0", "0", "NA", "+ Inf",
+      paste0("\U02212", "Inf")
     )
   )
 
@@ -399,9 +431,16 @@ test_that("the `fmt_integer()` fn can render in the Indian numbering system", {
        render_formats_test(context = "html"))[["num"]],
     c(
       "50 Lac", "1,000", "10", "12,345", "1,234", "123", "1", "0",
-      "26 Lac", "154 Cr", "64,25,64,826 Cr", "&minus;50 Cr", "&minus;1,000",
-      "&minus;10", "&minus;12,345", "&minus;1,234", "&minus;123", "&minus;1",
-      "0", "0", "0", "NA", " Inf Cr", "&minus;Inf Cr"
+      "26 Lac", "154 Cr", "64,25,64,826 Cr",
+      paste0("\U02212", "50 Cr"),
+      paste0("\U02212", "1,000"),
+      paste0("\U02212", "10"),
+      paste0("\U02212", "12,345"),
+      paste0("\U02212", "1,234"),
+      paste0("\U02212", "123"),
+      paste0("\U02212", "1"),
+      "0", "0", "0", "NA", " Inf Cr",
+      paste0("\U02212", "Inf Cr")
     )
   )
   expect_equal(
@@ -409,10 +448,17 @@ test_that("the `fmt_integer()` fn can render in the Indian numbering system", {
        fmt_integer(columns = num, suffixing = c("K", "Lacs", "Crores"), system = "ind") %>%
        render_formats_test(context = "html"))[["num"]],
     c(
-      "50 Lacs", "1 K", "10", "12 K", "1 K", "123", "1", "0", "26 Lacs",
-      "154 Crores", "64,25,64,826 Crores", "&minus;50 Crores", "&minus;1 K",
-      "&minus;10", "&minus;12 K", "&minus;1 K", "&minus;123", "&minus;1",
-      "0", "0", "0", "NA", " Inf Crores", "&minus;Inf Crores"
+      "50 Lacs", "1 K", "10", "12 K", "1 K", "123", "1",
+      "0", "26 Lacs", "154 Crores", "64,25,64,826 Crores",
+      paste0("\U02212", "50 Crores"),
+      paste0("\U02212", "1 K"),
+      paste0("\U02212", "10"),
+      paste0("\U02212", "12 K"),
+      paste0("\U02212", "1 K"),
+      paste0("\U02212", "123"),
+      paste0("\U02212", "1"),
+      "0", "0", "0", "NA", " Inf Crores",
+      paste0("\U02212", "Inf Crores")
     )
   )
   expect_equal(
@@ -421,9 +467,16 @@ test_that("the `fmt_integer()` fn can render in the Indian numbering system", {
        render_formats_test(context = "html"))[["num"]],
     c(
       "50 Lacs", "1,000", "10", "12,345", "1,234", "123", "1", "0",
-      "26 Lacs", "15,357 Lacs", "64,25,64,82,573 Lacs", "&minus;5,000 Lacs",
-      "&minus;1,000", "&minus;10", "&minus;12,345", "&minus;1,234",
-      "&minus;123", "&minus;1", "0", "0", "0", "NA", " Inf Lacs", "&minus;Inf Lacs"
+      "26 Lacs", "15,357 Lacs", "64,25,64,82,573 Lacs",
+      paste0("\U02212", "5,000 Lacs"),
+      paste0("\U02212", "1,000"),
+      paste0("\U02212", "10"),
+      paste0("\U02212", "12,345"),
+      paste0("\U02212", "1,234"),
+      paste0("\U02212", "123"),
+      paste0("\U02212", "1"),
+      "0", "0", "0", "NA", " Inf Lacs",
+      paste0("\U02212", "Inf Lacs")
     )
   )
   expect_equal(
