@@ -1,5 +1,3 @@
-context("Ensuring that the `fmt_passthrough()` function works as expected")
-
 test_that("the `fmt_passthrough()` function works correctly", {
 
   # Create an input data frame four columns: two
@@ -19,7 +17,7 @@ test_that("the `fmt_passthrough()` function works correctly", {
   tab <- gt(data_tbl)
 
   # Expect that the object has the correct classes
-  expect_is(tab, c("gt_tbl", "data.frame"))
+  expect_s3_class(tab, c("gt_tbl", "data.frame"))
 
   # Extract vectors from the table object for comparison
   # to the original dataset
