@@ -1,5 +1,3 @@
-context("Ensuring that the `gt()` function works as expected")
-
 # Function to skip tests if Suggested packages not available on system
 check_suggests <- function() {
   skip_if_not_installed("rvest")
@@ -8,10 +6,7 @@ check_suggests <- function() {
 
 # Gets the inner HTML text from a single value
 selection_text <- function(html, selection) {
-
-  html %>%
-    rvest::html_nodes(selection) %>%
-    rvest::html_text()
+  rvest::html_text(rvest::html_nodes(html, selection))
 }
 
 test_that("a gt table object contains the correct components", {
@@ -256,14 +251,15 @@ test_that("gt table can be made with grouped data -- one group", {
   built_tbl$`_row_groups` %>% expect_equal(c("grp_a", "grp_b"))
 
   built_tbl$`_groups_rows` %>%
-    expect_equivalent(
+    expect_equal(
       data.frame(
         group_id = c("grp_a", "grp_b"),
         group_label = c("grp_a", "grp_b"),
         row_start = c(1, 5),
         row_end = c(4, 8),
         stringsAsFactors = FALSE
-      )
+      ),
+      ignore_attr = TRUE
     )
 
   built_tbl$`_boxhead` %>% .[, 1:2] %>%
@@ -274,16 +270,10 @@ test_that("gt table can be made with grouped data -- one group", {
       )
     )
 
-  built_tbl$`_stub_df` %>%
-    expect_equivalent(
-      dplyr::tibble(
-        rownum_i = 1:8,
-        group_id = c(rep("grp_a", 4), rep("grp_b", 4)),
-        rowname = NA_character_,
-        group_label = c(rep("grp_a", 4), rep("grp_b", 4)),
-        built = c(rep("grp_a", 4), rep("grp_b", 4))
-      )
-    )
+  expect_equal(
+    unlist(built_tbl$`_stub_df`$group_label),
+    c(rep("grp_a", 4), rep("grp_b", 4))
+  )
 
   # Render the HTML table and read the HTML with `xml2`
   html_tbl <-
@@ -338,13 +328,14 @@ test_that("gt table can be made with grouped data - two groups", {
     expect_equal(table_groups)
 
   built_tbl$`_groups_rows` %>%
-    expect_equivalent(
+    expect_equal(
       dplyr::tibble(
         group_id = table_groups,
         group_label = table_groups,
         row_start = c(1, 3, 5, 7),
         row_end = c(2, 4, 6, 8)
-      )
+      ),
+      ignore_attr = TRUE
     )
 
   built_tbl$`_boxhead` %>% .[, 1:2] %>%
@@ -358,16 +349,15 @@ test_that("gt table can be made with grouped data - two groups", {
       )
     )
 
-  built_tbl$`_stub_df` %>%
-    expect_equivalent(
-      dplyr::tibble(
-        rownum_i = 1:8,
-        group_id = rep(table_groups, 2) %>% sort(),
-        rowname = NA_character_,
-        group_label = rep(table_groups, 2) %>% sort(),
-        built = rep(table_groups, 2) %>% sort()
-      )
-    )
+  expect_equal(
+    built_tbl$`_stub_df`$group_id,
+    built_tbl$`_stub_df`$built
+  )
+
+  expect_equal(
+    built_tbl$`_stub_df`$rowname,
+    rep(NA_character_, 8)
+  )
 
   # Render the HTML table and read the HTML with `xml2`
   html_tbl <-
@@ -429,7 +419,7 @@ test_that("The `gt()` groupname_col arg will override any grouped data", {
     )
 
   built_tbl$`_groups_rows` %>%
-    expect_equivalent(
+    expect_equal(
       data.frame(
         group_id = c(
           "2015-01-15", "2015-02-15", "2015-03-15", "2015-04-15",
@@ -440,7 +430,8 @@ test_that("The `gt()` groupname_col arg will override any grouped data", {
         row_start = 1:8,
         row_end = 1:8,
         stringsAsFactors = FALSE
-      )
+      ),
+      ignore_attr = TRUE
     )
 
   built_tbl$`_boxhead` %>% .[, 1:2] %>%
@@ -451,25 +442,34 @@ test_that("The `gt()` groupname_col arg will override any grouped data", {
       )
     )
 
-  built_tbl$`_stub_df` %>%
-    expect_equivalent(
-      dplyr::tibble(
-        rownum_i = 1:8,
-        group_id = c(
-          "2015-01-15", "2015-02-15", "2015-03-15", "2015-04-15",
-          "2015-05-15", "2015-06-15", "NA", "2015-08-15"
-        ),
-        rowname = NA_character_,
-        group_label = c(
-          "2015-01-15", "2015-02-15", "2015-03-15", "2015-04-15",
-          "2015-05-15", "2015-06-15", "NA", "2015-08-15"
-        ),
-        built = c(
-          "2015-01-15", "2015-02-15", "2015-03-15", "2015-04-15",
-          "2015-05-15", "2015-06-15", "NA", "2015-08-15"
-        )
-      )
+  expect_equal(
+    built_tbl$`_stub_df`$group_id,
+    c(
+      "2015-01-15", "2015-02-15", "2015-03-15", "2015-04-15",
+      "2015-05-15", "2015-06-15", "NA", "2015-08-15"
     )
+  )
+
+  expect_equal(
+    built_tbl$`_stub_df`$rowname,
+    rep(NA_character_, 8)
+  )
+
+  expect_equal(
+    unlist(built_tbl$`_stub_df`$group_label),
+    c(
+      "2015-01-15", "2015-02-15", "2015-03-15", "2015-04-15",
+      "2015-05-15", "2015-06-15", "NA", "2015-08-15"
+    )
+  )
+
+  expect_equal(
+    built_tbl$`_stub_df`$built,
+    c(
+      "2015-01-15", "2015-02-15", "2015-03-15", "2015-04-15",
+      "2015-05-15", "2015-06-15", "NA", "2015-08-15"
+    )
+  )
 
   # Render the HTML table and read the HTML with `xml2`
   html_tbl <-
@@ -546,14 +546,17 @@ test_that("The `gt()` `rowname_col` arg will be overridden by `rownames_to_stub
     )
 
   built_tbl$`_stub_df` %>%
-    expect_equivalent(
+    expect_equal(
       dplyr::tibble(
         rownum_i = 1:10,
         group_id = NA_character_,
         rowname = rownames(mtcars)[1:10],
+        row_id = rownames(mtcars)[1:10],
         group_label = list(NULL),
+        indent = NA_character_,
         built = ""
-      )
+      ),
+      ignore_attr = TRUE
     )
 
   # Render the HTML table and read the HTML with `xml2`
@@ -616,14 +619,17 @@ test_that("The `rowname` column will be safely included when `rownames_to_stub =
     )
 
   built_tbl$`_stub_df` %>%
-    expect_equivalent(
+    expect_equal(
       dplyr::tibble(
         rownum_i = 1:8,
         group_id = NA_character_,
         rowname = as.character(1:8),
+        row_id = as.character(1:8),
         group_label = list(NULL),
+        indent = NA_character_,
         built = ""
-      )
+      ),
+      ignore_attr = TRUE
     )
 
   # Render the HTML table and read the HTML with `xml2`
@@ -705,7 +711,7 @@ test_that("Escapable characters in rownames are handled correctly in each output
   expect_match( # stub from data frame's row names
     gt(tbl, rownames_to_stub = TRUE) %>%
       render_as_html(),
-    "<tr><td class=\"gt_row gt_right gt_stub\">&lt;em&gt;row_html&lt;/em&gt;</td>",
+    "<tr><th scope=\"row\" class=\"gt_row gt_left gt_stub\">&lt;em&gt;row_html&lt;/em&gt;</th>",
     fixed = TRUE
   )
   expect_match( # `column_1`
@@ -725,7 +731,7 @@ test_that("Escapable characters in rownames are handled correctly in each output
   expect_match( # stub from `column_1`
     gt(dplyr::as_tibble(tbl), rowname_col = "column_1") %>%
       render_as_html(),
-    "<tr><td class=\"gt_row gt_right gt_stub\">&lt;em&gt;html&lt;/em&gt;</td>",
+    "<tr><th scope=\"row\" class=\"gt_row gt_left gt_stub\">&lt;em&gt;html&lt;/em&gt;</th>",
     fixed = TRUE
   )
   expect_match( # `column_2`
@@ -820,23 +826,23 @@ test_that("Default locale settings are honored by formatting functions", {
 
   # `fmt_scientific()`
   (exibble_1 %>% gt() %>% fmt_scientific(num) %>% render_formats_test(context = "plain"))[["num"]] %>%
-    expect_equal("7.77 x 10(5)")
+    expect_equal("7.77 \U000D7 10^5")
   (exibble_1 %>% gt(locale = "fr") %>% fmt_scientific(num) %>% render_formats_test(context = "plain"))[["num"]] %>%
-    expect_equal("7,77 x 10(5)")
+    expect_equal("7,77 \U000D7 10^5")
   (exibble_1 %>% gt(locale = "en") %>% fmt_scientific(num, locale = "fr") %>% render_formats_test(context = "plain"))[["num"]] %>%
-    expect_equal("7,77 x 10(5)")
+    expect_equal("7,77 \U000D7 10^5")
   (exibble_1 %>% gt(locale = "fr") %>% fmt_scientific(num, locale = "de") %>% render_formats_test(context = "plain"))[["num"]] %>%
-    expect_equal("7,77 x 10(5)")
+    expect_equal("7,77 \U000D7 10^5")
 
   # `fmt_engineering()`
   (exibble_1 %>% gt() %>% fmt_engineering(num) %>% render_formats_test(context = "plain"))[["num"]] %>%
-    expect_equal("777.00 x 10(3)")
+    expect_equal("777.00 \U000D7 10^3")
   (exibble_1 %>% gt(locale = "fr") %>% fmt_engineering(num) %>% render_formats_test(context = "plain"))[["num"]] %>%
-    expect_equal("777,00 x 10(3)")
+    expect_equal("777,00 \U000D7 10^3")
   (exibble_1 %>% gt(locale = "en") %>% fmt_engineering(num, locale = "fr") %>% render_formats_test(context = "plain"))[["num"]] %>%
-    expect_equal("777,00 x 10(3)")
+    expect_equal("777,00 \U000D7 10^3")
   (exibble_1 %>% gt(locale = "fr") %>% fmt_engineering(num, locale = "de") %>% render_formats_test(context = "plain"))[["num"]] %>%
-    expect_equal("777,00 x 10(3)")
+    expect_equal("777,00 \U000D7 10^3")
 
   # `fmt_percent()`
   (exibble_1 %>% gt() %>% fmt_percent(num, scale_values = FALSE) %>% render_formats_test(context = "plain"))[["num"]] %>%
