@@ -1,12 +1,8 @@
-context("Ensuring that the information-providing functions work as expected")
-
 test_that("the `info_date_style()` function works correctly", {
 
   # Expect that the `info_date_style()` function produces an
   # information table with certain classes
-  expect_is(
-    info_date_style(),
-    c("gt_tbl", "data.frame"))
+  expect_s3_class(info_date_style(), c("gt_tbl", "data.frame"))
 
   # Expect the internal source data frame to be of
   # specific dimensions
@@ -14,16 +10,15 @@ test_that("the `info_date_style()` function works correctly", {
     info_date_style() %>%
       dt_data_get() %>%
       dim(),
-    c(14, 3))
+    c(14, 3)
+  )
 })
 
 test_that("the `info_time_style()` function works correctly", {
 
   # Expect that the `info_time_style()` function produces an
   # information table with certain classes
-  expect_is(
-    info_time_style(),
-    c("gt_tbl", "data.frame"))
+  expect_s3_class(info_time_style(), c("gt_tbl", "data.frame"))
 
   # Expect the internal source data frame to be of
   # specific dimensions
@@ -31,16 +26,15 @@ test_that("the `info_time_style()` function works correctly", {
     info_time_style() %>%
       dt_data_get() %>%
       dim(),
-    c(5, 3))
+    c(5, 3)
+  )
 })
 
 test_that("the `info_google_fonts()` function works correctly", {
 
   # Expect that the `info_google_fonts()` function produces an
   # information table with certain classes
-  expect_is(
-    info_google_fonts(),
-    c("gt_tbl", "data.frame"))
+  expect_s3_class(info_google_fonts(), c("gt_tbl", "data.frame"))
 
   # Expect the internal source data frame to be of
   # specific dimensions
@@ -48,5 +42,6 @@ test_that("the `info_google_fonts()` function works correctly", {
     info_google_fonts() %>%
       dt_data_get() %>%
       dim(),
-    c(38, 4))
+    c(38, 4)
+  )
 })
